@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: cae.cpp,v 1.94 2007/02/14 21:48:41 fredg Exp $
+//      $Id: cae.cpp,v 1.104 2008-08-18 16:09:07 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -46,15 +46,13 @@
 #include <qsqldatabase.h>
 #include <qsessionmanager.h>
 
-#include <rwavefile.h>
-#include <rconf.h>
-#include <rsocket.h>
-#include <cae_socket.h>
-
+#include <rdsocket.h>
+#include <rdconf.h>
 #include <rdcheck_daemons.h>
 #include <rddebug.h>
 #include <rdcmd_switch.h>
 
+#include <cae_socket.h>
 #include <cae.h>
 
 
@@ -62,12 +60,17 @@ struct RDMeterBlock *meter_block=NULL;
 int meter_block_id=-1;
 volatile bool exiting=false;
 RDConfig *rd_config;
+#ifdef JACK
+extern jack_client_t *jack_client;
+#endif  // JACK
 
 
-void LogLine(QString line)
+void LogLine(RDConfig::LogPriority prio,const QString &line)
 {
   FILE *file;
 
+  rd_config->log("caed",prio,line);
+
   if(rd_config->caeLogfile().isEmpty()) {
     return;
   }
@@ -117,11 +120,18 @@ MainObject::MainObject(QObject *parent,const char *name)
     new RDCmdSwitch(qApp->argc(),qApp->argv(),"caed",CAED_USAGE);
   delete cmd;
 
+  //
+  // LogLine references rd_config
+  // 
+  rd_config=new RDConfig(RD_CONF_FILE);
+  rd_config->load();
+
   //
   // Make sure we're the only instance running
   //
   if(CheckDaemon(RD_CAED_PID)) {
-    LogLine("ERROR caed aborting - multiple instances not allowed");
+    LogLine(RDConfig::LogErr,
+	    "ERROR caed aborting - multiple instances not allowed");
     exit(1);
   }
 
@@ -169,26 +179,23 @@ MainObject::MainObject(QObject *parent,const char *name)
   jack_client=NULL;
 #endif  // JACK
 
-  rd_config=new RDConfig(CAE_DEFAULT_CONF_FILE);
-  rd_config->load();
- 
   server=new CaeSocket(CAED_TCP_PORT,0,this,"socket");
   if(!server->ok()) {
-    LogLine("ERROR caed aborting - CaeSocket() server not ok");
+    LogLine(RDConfig::LogErr,"ERROR caed aborting - CaeSocket() server not ok");
     exit(1);
   }
   connect(server,SIGNAL(connection(int)),this,SLOT(newConnection(int)));
 
   if(!debug) {
-    RDetach();
+    RDDetach(rd_config->logCoreDumpDirectory());
   }
 
   signal(SIGHUP,SigHandler);
   signal(SIGINT,SigHandler);
   signal(SIGTERM,SigHandler);
 
-  if(!RWritePid(RD_PID_DIR,"caed.pid",rd_config->uid())) {
-    LogLine("can't write pid file");
+  if(!RDWritePid(RD_PID_DIR,"caed.pid",rd_config->uid())) {
+    LogLine(RDConfig::LogErr,"can't write pid file");
     fprintf(stderr,"caed: can't write pid file\n");
     exit(1);
   }
@@ -208,9 +215,9 @@ MainObject::MainObject(QObject *parent,const char *name)
       shmget(RD_METER_SHM_KEY,sizeof(struct RDMeterBlock),
 	     IPC_CREAT|IPC_EXCL|S_IRUSR|S_IWUSR|S_IRGRP|S_IROTH))<0) {
     if(errno!=EEXIST) {
-      LogLine(QString().sprintf("can't allocate shared memory segment, error:%d",
-			      errno));
-      fprintf(stderr,"caed: can't allocate shared memory segment, error:%d\n", errno);
+      LogLine(RDConfig::LogWarning,QString().
+	      sprintf("can't allocate shared memory segment, error:%d",
+		      errno));
       exit(1);
     }
     // The shmget() error was due to an existing segment, so try to get it, release it, and re-get it.
@@ -218,9 +225,8 @@ MainObject::MainObject(QObject *parent,const char *name)
     shmctl(meter_block_id,IPC_RMID,NULL);
     if((meter_block_id=shmget(RD_METER_SHM_KEY,sizeof(struct RDMeterBlock),
 			      IPC_CREAT|IPC_EXCL|S_IRUSR|S_IWUSR|S_IRGRP|S_IROTH))<0) {
-      LogLine(QString().sprintf("can't allocate shared memory segment after trying to destroy, error:%d",
+      LogLine(RDConfig::LogErr,QString().sprintf("can't allocate shared memory segment after trying to destroy, error:%d",
 			      errno));
-      fprintf(stderr,"caed: can't allocate shared memory segment after trying to destroy, error:%d\n", errno);
       exit(1);
     }
   }
@@ -245,8 +251,8 @@ MainObject::MainObject(QObject *parent,const char *name)
   //
   QSqlDatabase *db=QSqlDatabase::addDatabase(rd_config->mysqlDriver());
   if(!db) {
-    LogLine("can't open mySQL database");
-    printf("caed: can't open mySQL database\n");
+    LogLine(RDConfig::LogErr,"can't open mySQL database");
+    fprintf(stderr,"caed: can't open mySQL database");
     exit(1);
   }
   db->setDatabaseName(rd_config->mysqlDbname());
@@ -254,7 +260,7 @@ MainObject::MainObject(QObject *parent,const char *name)
   db->setPassword(rd_config->mysqlPassword());
   db->setHostName(rd_config->mysqlHostname());
   if(!db->open()) {
-    LogLine("unable to connect to mySQL Server");
+    LogLine(RDConfig::LogErr,"unable to connect to mySQL Server");
     printf("caed: unable to connect to mySQL Server");
     db->removeDatabase(rd_config->mysqlDbname());
     exit(1);
@@ -299,6 +305,7 @@ MainObject::MainObject(QObject *parent,const char *name)
   bool jack_running=false;
   int sched_policy=SCHED_OTHER;
   struct sched_param sched_params;
+  int result = 0;
   memset(&sched_params,0,sizeof(struct sched_param));
 #ifdef JACK
   if(jack_client!=NULL) {
@@ -307,10 +314,20 @@ MainObject::MainObject(QObject *parent,const char *name)
 #ifdef ALSA
     for(int i=0;i<RD_MAX_CARDS;i++) {
       if(cae_driver[i]==RDStation::Alsa) {
-	pthread_setschedparam(alsa_play_format[i].thread,sched_policy,
-			      &sched_params);
-	pthread_setschedparam(alsa_capture_format[i].thread,sched_policy,
-			      &sched_params);
+	if (!alsa_play_format[i].exiting) {
+	  int r = pthread_setschedparam(alsa_play_format[i].thread,sched_policy,
+					&sched_params);
+	  if (r) {
+	    result = r;
+	  }	
+	}
+	if (!alsa_capture_format[i].exiting) {
+	  int r = pthread_setschedparam(alsa_capture_format[i].thread,sched_policy,
+					&sched_params);
+	  if (r) {
+	    result = r;
+	  }
+	}
       }
     }
 #endif  // ALSA
@@ -325,20 +342,40 @@ MainObject::MainObject(QObject *parent,const char *name)
 #ifdef ALSA
     for(int i=0;i<RD_MAX_CARDS;i++) {
       if(cae_driver[i]==RDStation::Alsa) {
-	pthread_setschedparam(alsa_play_format[i].thread,sched_policy,
-			      &sched_params);
-	pthread_setschedparam(alsa_capture_format[i].thread,sched_policy,
-			      &sched_params);
+	if (!alsa_play_format[i].exiting) {
+	  int r = pthread_setschedparam(alsa_play_format[i].thread,sched_policy,
+					&sched_params);
+	  if (r) {
+	    result = r;
+	  }
+	}
+	if (!alsa_capture_format[i].exiting) {
+	  int r = pthread_setschedparam(alsa_capture_format[i].thread,sched_policy,
+					&sched_params);
+	  if (r) {
+	    result = r;
+	  }
+	}
       }
     }
 #endif  // ALSA
-    LogLine(QString().sprintf("using realtime scheduling, priority=%d",
-			      sched_params.sched_priority));
     if(sched_params.sched_priority>sched_get_priority_min(sched_policy)) {
       sched_params.sched_priority--;
     }
-    pthread_setschedparam(pthread_self(),sched_policy,&sched_params);
+    int r = pthread_setschedparam(pthread_self(),sched_policy,&sched_params);
+    if (r) {
+      result = r;
+    }
     mlockall(MCL_FUTURE);
+    if (result){
+          LogLine(RDConfig::LogWarning,QString().
+		  sprintf("Unable to set realtime scheduling: %s",
+			  strerror (result)));
+    } else {
+    LogLine(RDConfig::LogInfo,QString().
+	    sprintf("using realtime scheduling, priority=%d",
+		    sched_params.sched_priority));
+    }
   }
 
   //
@@ -357,9 +394,9 @@ MainObject::MainObject(QObject *parent,const char *name)
   }
 */
   if(rd_config->enableMixerLogging()) {
-    LogLine("mixer logging enabled");
+    LogLine(RDConfig::LogNotice,"mixer logging enabled");
   }
-  LogLine("cae started");
+  LogLine(RDConfig::LogInfo,"cae started");
 }
 
 
@@ -375,11 +412,11 @@ void MainObject::newConnection(int fd)
     i++;
   }
   if(i==CAE_MAX_CONNECTIONS) {      // Table full, drop it on the floor
-    LogLine("connection refused due to full socket table");
+    LogLine(RDConfig::LogErr,"connection refused due to full socket table");
     close(fd);
     return;
   }
-  socket[i]=new RSocket(i,this,"socket_0");
+  socket[i]=new RDSocket(i,this,"socket_0");
   socket[i]->setSocket(fd);
   connect(socket[i],SIGNAL(readyReadID(int)),this,SLOT(socketData(int)));
   connect(socket[i],SIGNAL(connectionClosedID(int)),
@@ -465,8 +502,8 @@ void MainObject::updateMeters()
       shmdt(meter_block);
       shmctl(meter_block_id,IPC_RMID,NULL);
     }
-    RDeletePid(RD_PID_DIR,"caed.pid");
-    LogLine("cae exiting");
+    RDDeletePid(RD_PID_DIR,"caed.pid");
+    LogLine(RDConfig::LogInfo,"cae exiting");
     exit(0);
   }
 
@@ -705,14 +742,14 @@ void MainObject::DispatchCommand(int ch)
       EchoCommand(ch,temp);
       return;
     }
-    wavename=QString().sprintf("%s/%s.%s",RD_AUDIO_ROOT,args[ch][2],
-			       RD_AUDIO_EXTENSION);
+    wavename = rd_config->audioFileName (QString(args[ch][2]));
     switch(cae_driver[card]) {
 	case RDStation::Hpi:
 	  if(!hpiLoadPlayback(card,wavename,&new_stream)) {
 	    sprintf(temp,"LP %d %s -1 -1 -!",card,args[ch][2]);
 	    EchoCommand(ch,temp);
-	    LogLine(QString().sprintf("unable to allocate stream for card %d",
+	    LogLine(RDConfig::LogErr,
+		    QString().sprintf("unable to allocate stream for card %d",
 				      card));
 	    return;
 	  }
@@ -720,31 +757,34 @@ void MainObject::DispatchCommand(int ch)
 
 	case RDStation::Alsa:
 	  if(!alsaLoadPlayback(card,wavename,&new_stream)) {
-	    sprintf(temp,"LP %d %d %s -1 -!",card,stream,args[ch][3]);
+	    sprintf(temp,"LP %d %s -1 -1 -!",card,args[ch][2]);
 	    EchoCommand(ch,temp);
-	    LogLine(QString().sprintf("unable to allocate stream for card %d",
-				      card));
+	    LogLine(RDConfig::LogErr,QString().
+		    sprintf("unable to allocate stream for card %d",
+			    card));
 	    return;
 	  }
 	  break;
 
 	case RDStation::Jack:
 	  if(!jackLoadPlayback(card,wavename,&new_stream)) {
-	    sprintf(temp,"LP %d %d %s -1 -!",card,stream,args[ch][3]);
+	    sprintf(temp,"LP %d %s -1 -1 -!",card,args[ch][2]);
 	    EchoCommand(ch,temp);
-	    LogLine(QString().sprintf("unable to allocate stream for card %d",
-				      card));
+	    LogLine(RDConfig::LogErr,QString().
+		    sprintf("unable to allocate stream for card %d",
+			    card));
 	    return;
 	  }
 	  break;
 
 	default:
-	  sprintf(temp,"LP %d %d %s -1 -!",card,stream,args[ch][3]);
+	  sprintf(temp,"LP %d %s -1 -1 -!",card,args[ch][2]);
 	  EchoCommand(ch,temp);
 	  return;
     }
     if((handle=GetHandle(card,new_stream))>=0) {
-      LogLine(QString().sprintf("*** clearing stale stream assignment, card=%d  stream=%d ***",card,new_stream));
+      LogLine(RDConfig::LogErr,QString().
+	      sprintf("*** clearing stale stream assignment, card=%d  stream=%d ***",card,new_stream));
       play_handle[handle].card=-1;
       play_handle[handle].stream=-1;
       play_handle[handle].owner=-1;
@@ -754,7 +794,7 @@ void MainObject::DispatchCommand(int ch)
     play_handle[handle].stream=new_stream;
     play_handle[handle].owner=ch;
     play_owner[card][new_stream]=ch;
-    LogLine(QString().
+    LogLine(RDConfig::LogInfo,QString().
 	    sprintf("LoadPlayback  Card: %d  Stream: %d  Name: %s  Handle: %d",
 		    card,new_stream,(const char *)wavename,handle));
     sprintf(temp,"LP %d %s %d %d +!",card,args[ch][2],new_stream,handle);
@@ -774,7 +814,7 @@ void MainObject::DispatchCommand(int ch)
 	  case RDStation::Hpi:
 	    if(hpiUnloadPlayback(card,stream)) {
 	      play_owner[card][stream]=-1;
-	      LogLine(QString().
+	      LogLine(RDConfig::LogInfo,QString().
 		      sprintf("UnloadPlayback - Card: %d  Stream: %d  Handle: %d",
 			      card,stream,handle));
 	      EchoArgs(ch,'+');
@@ -787,7 +827,7 @@ void MainObject::DispatchCommand(int ch)
 	  case RDStation::Alsa:
 	    if(alsaUnloadPlayback(card,stream)) {
 	      play_owner[card][stream]=-1;
-	      LogLine(QString().
+	      LogLine(RDConfig::LogInfo,QString().
 		      sprintf("UnloadPlayback - Card: %d  Stream: %d  Handle: %d",
 			      card,stream,handle));
 	      EchoArgs(ch,'+');
@@ -800,7 +840,7 @@ void MainObject::DispatchCommand(int ch)
 	  case RDStation::Jack:
 	    if(jackUnloadPlayback(card,stream)) {
 	      play_owner[card][stream]=-1;
-	      LogLine(QString().
+	      LogLine(RDConfig::LogInfo,QString().
 		      sprintf("UnloadPlayback - Card: %d  Stream: %d  Handle: %d",
 			      card,stream,handle));
 	      EchoArgs(ch,'+');
@@ -839,13 +879,13 @@ void MainObject::DispatchCommand(int ch)
       switch(cae_driver[card]) {
 	  case RDStation::Hpi:
 	    if(hpiPlaybackPosition(card,stream,pos)) {
-	      LogLine(QString().
+	      LogLine(RDConfig::LogInfo,QString().
 		   sprintf("PlaybackPosition - Card: %d  Stream: %d  Pos: %d  Handle: %d",
 			   card,stream,pos,handle));
 	      EchoArgs(ch,'+');
 	    }
 	    else {
-	      LogLine(QString().
+	      LogLine(RDConfig::LogNotice,QString().
 		   sprintf("*** PlaybackPosition out of bounds - Card: %d  Stream: %d  Pos: %d   Handle: %d***",
 			   card,stream,pos,handle));
 	      EchoArgs(ch,'-');
@@ -854,7 +894,7 @@ void MainObject::DispatchCommand(int ch)
 
 	  case RDStation::Alsa:
 	    if(alsaPlaybackPosition(card,stream,pos)) {
-	      LogLine(QString().
+	      LogLine(RDConfig::LogInfo,QString().
 		   sprintf("PlaybackPosition - Card: %d  Stream: %d  Pos: %d  Handle: %d",
 			   card,stream,pos,handle));
 	      EchoArgs(ch,'+');
@@ -866,7 +906,7 @@ void MainObject::DispatchCommand(int ch)
 
 	  case RDStation::Jack:
 	    if(jackPlaybackPosition(card,stream,pos)) {
-	      LogLine(QString().
+	      LogLine(RDConfig::LogInfo,QString().
 		   sprintf("PlaybackPosition - Card: %d  Stream: %d  Pos: %d  Handle: %d",
 			   card,stream,pos,handle));
 	      EchoArgs(ch,'+');
@@ -949,7 +989,7 @@ void MainObject::DispatchCommand(int ch)
 	      EchoArgs(ch,'-');
 	      return;
       }
-      LogLine(QString().
+      LogLine(RDConfig::LogInfo,QString().
        sprintf("Play - Card: %d  Stream: %d  Handle: %d  Length: %d  Speed: %d  Pitch: %d",
 	       card,stream,handle,play_length[card][stream],
 	       play_speed[card][stream],flag));
@@ -994,7 +1034,7 @@ void MainObject::DispatchCommand(int ch)
 	    EchoArgs(ch,'-');
 	    return;
       }
-      LogLine(QString().
+      LogLine(RDConfig::LogInfo,QString().
 	      sprintf("StopPlayback - Card: %d  Stream: %d  Handle: %d",
 		      card,stream,handle));
       EchoArgs(ch,'+');
@@ -1057,8 +1097,7 @@ void MainObject::DispatchCommand(int ch)
 	EchoArgs(ch,'-');
  	return;
       }
-      wavename=QString().sprintf("%s/%s.%s",RD_AUDIO_ROOT,args[ch][7],
-				 RD_AUDIO_EXTENSION);
+      wavename = rd_config->audioFileName(QString(args[ch][7]));
       unlink(wavename);  // So we don't trainwreck any current playouts!
       switch(cae_driver[card]) {
 	  case RDStation::Hpi:
@@ -1089,7 +1128,7 @@ void MainObject::DispatchCommand(int ch)
 	    EchoArgs(ch,'-');
 	    return;
       }
-      LogLine(QString().
+      LogLine(RDConfig::LogInfo,QString().
 	      sprintf("LoadRecord - Card: %d  Stream: %d  Coding: %d  Chans: %d  SampRate: %d  BitRate: %d  Name: %s",
 		      card,stream,coding,channels,sample_rate,bit_rate,
 		      (const char *)wavename));
@@ -1135,7 +1174,7 @@ void MainObject::DispatchCommand(int ch)
 	    return;
       }
       record_owner[card][stream]=-1;
-      LogLine(QString().
+      LogLine(RDConfig::LogInfo,QString().
 	      sprintf("UnloadRecord - Card: %d  Stream: %d",
 		      card,stream));
       EchoArgs(ch,'+');
@@ -1190,7 +1229,7 @@ void MainObject::DispatchCommand(int ch)
 	    EchoArgs(ch,'-');
 	    return;
       }
-      LogLine(QString().
+      LogLine(RDConfig::LogInfo,QString().
 	      sprintf("Record - Card: %d  Stream: %d  Length: %d  Thres: %d",
 		      card,stream,record_length[card][stream],
 		      record_threshold[card][stream]));
@@ -1234,7 +1273,7 @@ void MainObject::DispatchCommand(int ch)
 	  EchoArgs(ch,'-');
 	  return;
     }
-    LogLine(QString().
+    LogLine(RDConfig::LogInfo,QString().
 	    sprintf("StopRecord - Card: %d  Stream: %d",
 		    card,stream));
     return;
@@ -1270,7 +1309,7 @@ void MainObject::DispatchCommand(int ch)
 	  return;
     }
     if(rd_config->enableMixerLogging()) {
-      LogLine(QString().
+      LogLine(RDConfig::LogInfo,QString().
 	      sprintf("SetInputVolume - Card: %d  Stream: %d Level: %d",
 		      card,stream,level));
     }
@@ -1312,7 +1351,7 @@ void MainObject::DispatchCommand(int ch)
 	  return;
     }
     if(rd_config->enableMixerLogging()) {
-      LogLine(QString().
+      LogLine(RDConfig::LogInfo,QString().
 	      sprintf("SetOutputVolume - Card: %d  Stream: %d  Port: %d  Level: %d",
 		      card,stream,port,level));
     }
@@ -1355,7 +1394,7 @@ void MainObject::DispatchCommand(int ch)
 	  return;
     }
     if(rd_config->enableMixerLogging()) {
-      LogLine(QString().
+      LogLine(RDConfig::LogInfo,QString().
 	      sprintf("FadeOutputVolume - Card: %d  Stream: %d  Port: %d  Level: %d  Length: %d",
 		      card,stream,port,level,length));
     }
@@ -1397,7 +1436,7 @@ void MainObject::DispatchCommand(int ch)
 	  return;
     }
     if(rd_config->enableMixerLogging()) {
-      LogLine(QString().
+      LogLine(RDConfig::LogInfo,QString().
 	      sprintf("SetInputLevel - Card: %d  Port: %d  Level: %d",
 		      card,port,level));
     }
@@ -1439,7 +1478,7 @@ void MainObject::DispatchCommand(int ch)
 	  return;
     }
     if(rd_config->enableMixerLogging()) {
-      LogLine(QString().
+      LogLine(RDConfig::LogInfo,QString().
 	      sprintf("SetOutputLevel - Card: %d  Port: %d  Level: %d",
 		      card,port,level));
     }
@@ -1481,7 +1520,7 @@ void MainObject::DispatchCommand(int ch)
 	  return;
     }
     if(rd_config->enableMixerLogging()) {
-      LogLine(QString().
+      LogLine(RDConfig::LogInfo,QString().
 	      sprintf("SetInputMode - Card: %d  Port: %d  Mode: %d",
 		      card,port,mode));
     }
@@ -1523,7 +1562,7 @@ void MainObject::DispatchCommand(int ch)
 	  return;
     }
     if(rd_config->enableMixerLogging()) {
-      LogLine(QString().
+      LogLine(RDConfig::LogInfo,QString().
 	      sprintf("SetOutputMode - Card: %d  Port: %d  Mode: %d",
 		      card,port,mode));
     }
@@ -1564,7 +1603,7 @@ void MainObject::DispatchCommand(int ch)
 	  return;
     }
     if(rd_config->enableMixerLogging()) {
-      LogLine(QString().
+      LogLine(RDConfig::LogInfo,QString().
 	      sprintf("SetInputVOXLevel - Card: %d  Stream: %d  Level: %d",
 		      card,stream,level));
     }
@@ -1606,7 +1645,7 @@ void MainObject::DispatchCommand(int ch)
 	  return;
     }
     if(rd_config->enableMixerLogging()) {
-      LogLine(QString().
+      LogLine(RDConfig::LogInfo,QString().
 	      sprintf("SetInputType - Card: %d  Port: %d  Type: %d",
 		      card,port,type));
     }
@@ -1649,7 +1688,7 @@ void MainObject::DispatchCommand(int ch)
 	  return;
     }
     if(rd_config->enableMixerLogging()) {
-      LogLine(QString().
+      LogLine(RDConfig::LogInfo,QString().
 	      sprintf("SetPassthroughLevel - Card: %d  InPort: %d  OutPort: %d Level: %d",
 		      card,in_port,out_port,level));
     }
@@ -1697,7 +1736,7 @@ void MainObject::KillSocket(int ch)
 	      break;
 
 	    default:
-	      LogLine("tried to kill unowned socket!");
+	      LogLine(RDConfig::LogNotice,"tried to kill unowned socket!");
 	      break;
 	}
 	record_length[i][j]=0;
@@ -1897,7 +1936,8 @@ long MainObject::Resample(float *data_in,float *data_out,long frames,
       resample_buffer[0][j]=data_in[j*chans+i];
     }
     if((err=src_simple(&src_data,SRC_SINC_MEDIUM_QUALITY,1))!=0) {
-      LogLine(QString().sprintf("SRC Error: %s",src_strerror(err)));
+      LogLine(RDConfig::LogErr,QString().
+	      sprintf("SRC Error: %s",src_strerror(err)));
     }
     for(int j=0;j<src_data.output_frames_gen;j++) {
       data_out[j*chans+i]=resample_buffer[1][j];
@@ -1964,7 +2004,7 @@ void MainObject::ClearDriverEntries(RDStation *station)
 
 /* This is an overloaded virtual function that gets called on session end.  We use it to ensure shm is destroyed */
 void QApplication::commitData(QSessionManager &sm) {
-  LogLine("cae commitData()");
+  LogLine(RDConfig::LogDebug,"cae commitData()");
   shmctl(meter_block_id,IPC_RMID,NULL);
   return;
 };
@@ -1972,7 +2012,7 @@ void QApplication::commitData(QSessionManager &sm) {
 /* This is an overloaded virtual function to tell a session manager not to restart this daemon. */
 void QApplication::saveState(QSessionManager &sm) {
   sm.setRestartHint(QSessionManager::RestartNever);
-  LogLine("cae saveState(), set restart hint to Never");
+  LogLine(RDConfig::LogDebug,"cae saveState(), set restart hint to Never");
   return;
 };
 
@@ -1982,7 +2022,7 @@ int main(int argc,char *argv[])
   QApplication a(argc,argv,false);
   new MainObject(NULL,"main");
   rc=a.exec();
-  LogLine(QString().sprintf("cae post a.exec() rc:%d", rc));
+  LogLine(RDConfig::LogDebug,QString().sprintf("cae post a.exec() rc:%d", rc));
   shmctl(meter_block_id,IPC_RMID,NULL);
   return rc;
 }
