@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: cae_hpi.cpp,v 1.31 2007/12/26 17:44:03 grauf Exp $
+//      $Id: cae_hpi.cpp,v 1.35 2008-07-18 20:06:10 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -60,7 +60,7 @@ bool MainObject::hpiLoadPlayback(int card,QString wavename,int *stream)
   RDHPIPlayStream *playstream=new RDHPIPlayStream(sound_card);
   playstream->setCard(card);
   if(playstream->openWave(wavename)!=RDHPIPlayStream::Ok) {
-    LogLine(QString().sprintf(
+    LogLine(RDConfig::LogNotice,QString().sprintf(
             "Error: hpiLoadPlayback(%s)   openWave() failed to open file",
             (const char *) wavename) );
     delete playstream;
@@ -477,8 +477,7 @@ void MainObject::hpiGetOutputPosition(int card,unsigned *pos)
       pos[i]=0;
     }
     else {
-      pos[i]=((unsigned long long)play[card][i]->currentPosition() * 1000)/
-	play[card][i]->getSamplesPerSec();
+      pos[i]=((unsigned long long)play[card][i]->currentPosition());
     }
   }
 #endif  // HPI
