@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcart.cpp,v 1.59 2007/10/26 17:29:41 fredg Exp $
+//      $Id: rdcart.cpp,v 1.61.2.1 2008-10-28 19:24:20 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -32,6 +32,7 @@
 #include <rdcart.h>
 #include <rdcut.h>
 #include <rdtextvalidator.h>
+#include <rdescape_string.h>
 
 
 RDCart::RDCart(unsigned number)
@@ -100,7 +101,7 @@ bool RDCart::selectCut(QString *cut,const QTime &time) const
   }
   if(cutname.isEmpty()) {   // No valid cuts, try the evergreen
 #ifndef WIN32
-    syslog(LOG_USER|LOG_WARNING,"RDCart::selectCut(): no valid cuts, trying evergreen, SQL=%s",(const char *)sql);
+    // syslog(LOG_USER|LOG_WARNING,"RDCart::selectCut(): no valid cuts, trying evergreen, SQL=%s",(const char *)sql);
 #endif  // WIN32
     sql=QString().sprintf("select CUT_NAME,WEIGHT,LOCAL_COUNTER\
                            from CUTS where (CART_NUMBER=%u)&&\
@@ -113,7 +114,7 @@ bool RDCart::selectCut(QString *cut,const QTime &time) const
   }
   if(cutname.isEmpty()) {
 #ifndef WIN32
-    syslog(LOG_USER|LOG_WARNING,"RDCart::selectCut(): no valid evergreen cuts, SQL=%s",(const char *)sql);
+    // syslog(LOG_USER|LOG_WARNING,"RDCart::selectCut(): no valid evergreen cuts, SQL=%s",(const char *)sql);
 #endif  // WIN32
   }
   *cut=cutname;
@@ -648,43 +649,43 @@ void RDCart::setMetadata(RDWaveData *data)
   QString sql="update CART set ";
   if(!data->title().isEmpty()) {
     sql+=QString().sprintf("TITLE=\"%s\",",(const char *)
-		    RDTextValidator::stripString(data->title()).utf8());
+		    RDEscapeString(data->title()).utf8());
   }
   if(!data->artist().isEmpty()) {
     sql+=QString().sprintf("ARTIST=\"%s\",",(const char *)
-		    RDTextValidator::stripString(data->artist()).utf8());
+		    RDEscapeString(data->artist()).utf8());
   }
   if(!data->album().isEmpty()) {
     sql+=QString().sprintf("ALBUM=\"%s\",",(const char *)
-		    RDTextValidator::stripString(data->album()).utf8());
+		    RDEscapeString(data->album()).utf8());
   }
   if(data->releaseYear()>0) {
     sql+=QString().sprintf("YEAR=\"%04d-01-01\",",data->releaseYear());
   }
   if(!data->label().isEmpty()) {
     sql+=QString().sprintf("LABEL=\"%s\",",(const char *)
-		    RDTextValidator::stripString(data->label()).utf8());
+		    RDEscapeString(data->label()).utf8());
   }
   if(!data->client().isEmpty()) {
     sql+=QString().sprintf("CLIENT=\"%s\",",(const char *)
-		    RDTextValidator::stripString(data->client()).utf8());
+		    RDEscapeString(data->client()).utf8());
   }
   if(!data->agency().isEmpty()) {
     sql+=QString().sprintf("AGENCY=\"%s\",",(const char *)
-		    RDTextValidator::stripString(data->agency()).utf8());
+		    RDEscapeString(data->agency()).utf8());
   }
   if(!data->publisher().isEmpty()) {
     sql+=QString().sprintf("PUBLISHER=\"%s\",",
 			   (const char *)
-					   RDTextValidator::stripString(data->publisher()).utf8());
+					   RDEscapeString(data->publisher()).utf8());
   }
   if(!data->composer().isEmpty()) {
     sql+=QString().sprintf("COMPOSER=\"%s\",",
-    (const char *)RDTextValidator::stripString(data->composer()).utf8());
+    (const char *)RDEscapeString(data->composer()).utf8());
   }
   if(!data->userDefined().isEmpty()) {
     sql+=QString().sprintf("USER_DEFINED=\"%s\",",
-    (const char *)RDTextValidator::stripString(data->userDefined()).utf8());
+    (const char *)RDEscapeString(data->userDefined()).utf8());
   }
   if(sql.right(1)==",") {
     sql=sql.left(sql.length()-1);
@@ -1009,6 +1010,7 @@ QString RDCart::GetNextCut(RDSqlQuery *q) const
     }
   }
 #ifndef WIN32
+/*  Random rotation disabled -- FFG 4/2/2008
   switch(playOrder()) {
       case RDCart::Random:
 	q->seek(-1);
@@ -1027,6 +1029,7 @@ QString RDCart::GetNextCut(RDSqlQuery *q) const
       default:
 	break;
   }
+*/
 #endif  // WIN32
   return cutname;
 }
@@ -1125,7 +1128,7 @@ void RDCart::SetRow(const QString &param,const QString &value) const
 
   sql=QString().sprintf("UPDATE CART SET %s=\"%s\" WHERE NUMBER=%u",
 			(const char *)param,
-			(const char *)value.utf8(),
+			(const char *)RDEscapeString(value.utf8()),
 			cart_number);
   q=new RDSqlQuery(sql);
   delete q;
