@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcut_dialog.cpp,v 1.23 2007/07/09 07:21:12 stgabriel Exp $
+//      $Id: rdcut_dialog.cpp,v 1.25 2007-12-12 19:20:37 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -23,12 +23,14 @@
 #include <qpushbutton.h>
 #include <qlabel.h>
 #include <qsqlquery.h>
+#include <qapplication.h>
+#include <qeventloop.h>
 
 #include <rdcut_dialog.h>
 #include <rdcart_search_text.h>
 #include <rdtextvalidator.h>
 #include <rdadd_cart.h>
-
+#include <rddb.h>
 //
 // Icons
 //
@@ -36,9 +38,10 @@
 #include "../icons/rml5.xpm"
 
 
-RDCutDialog::RDCutDialog(QString *cutname,QString *filter,QString *group,
-			 QString username,bool show_clear,bool allow_add,
-			 bool exclude_tracks,QWidget *parent,const char *name)
+RDCutDialog::RDCutDialog(QString *cutname,RDStation *station,QString *filter,
+			 QString *group,QString username,bool show_clear,
+			 bool allow_add,bool exclude_tracks,
+			 QWidget *parent,const char *name)
   : QDialog(parent,name,true)
 {
   cut_cutname=cutname;
@@ -46,6 +49,7 @@ RDCutDialog::RDCutDialog(QString *cutname,QString *filter,QString *group,
   cut_group=group;
   cut_username=username;
   cut_allow_clear=show_clear;
+  cut_filter_mode=station->filterMode();
 
   if(filter==NULL) {
     cut_filter=new QString();
@@ -69,6 +73,8 @@ RDCutDialog::RDCutDialog(QString *cutname,QString *filter,QString *group,
   //
   QFont label_font("Helvetica",12,QFont::Bold);
   label_font.setPixelSize(12);
+  QFont progress_font("Helvetica",16,QFont::Bold);
+  progress_font.setPixelSize(16);
 
   //
   // Fix the Window Size
@@ -83,25 +89,48 @@ RDCutDialog::RDCutDialog(QString *cutname,QString *filter,QString *group,
   //
   RDTextValidator *validator=new RDTextValidator(this,"validator");
 
+  //
+  // Progress Dialog
+  //
+  cut_progress_dialog=
+    new QProgressDialog(tr("Please Wait..."),"Cancel",10,this,
+			"cut_progress_dialog",false,
+			Qt::WStyle_Customize|Qt::WStyle_NormalBorder);
+  cut_progress_dialog->setCaption(" ");
+  QLabel *label=new QLabel(tr("Please Wait..."),cut_progress_dialog);
+  label->setAlignment(AlignCenter);
+  label->setFont(progress_font);
+  cut_progress_dialog->setLabel(label);
+  cut_progress_dialog->setCancelButton(NULL);
+  cut_progress_dialog->setMinimumDuration(2000);
+
   //
   // Filter Selector
   //
   cut_filter_edit=new QLineEdit(this,"cut_filter_edit");
-  cut_filter_edit->setGeometry(100,10,360,20);
   cut_filter_edit->setValidator(validator);
-  QLabel *label=new QLabel(cut_filter_edit,tr("Cart Filter:"),
-			   this,"cut_filter_label");
+  label=new QLabel(cut_filter_edit,tr("Cart Filter:"),this,"cut_filter_label");
   label->setGeometry(10,10,85,20);
   label->setAlignment(AlignRight|AlignVCenter);
   label->setFont(label_font);
   connect(cut_filter_edit,SIGNAL(textChanged(const QString &)),
 	  this,SLOT(filterChangedData(const QString &)));
 
+  //
+  // Filter Search Button
+  //
+  cut_search_button=new QPushButton(this,"cut_search_button");
+  cut_search_button->setGeometry(sizeHint().width()-140,8,60,24);
+  cut_search_button->setText(tr("&Search"));
+  cut_search_button->setFont(label_font);
+  connect(cut_search_button,SIGNAL(clicked()),this,SLOT(searchButtonData()));
+
   //
   // Filter Clear Button
   //
   cut_clear_button=new QPushButton(this,"cut_clear_button");
-  cut_clear_button->setGeometry(470,8,60,24);
+  cut_clear_button->setGeometry(sizeHint().width()-70,8,60,24);
+  cut_clear_button->setFont(label_font);
   cut_clear_button->setText(tr("C&lear"));
   connect(cut_clear_button,SIGNAL(clicked()),this,SLOT(clearData()));
 
@@ -109,7 +138,7 @@ RDCutDialog::RDCutDialog(QString *cutname,QString *filter,QString *group,
   // Group Selector
   //
   cut_group_box=new QComboBox(this,"cut_clear_box");
-  cut_group_box->setGeometry(100,35,160,20);
+  cut_group_box->setGeometry(100,35,140,20);
   label=new QLabel(cut_filter_edit,tr("Group:"),this,"cut_group_label");
   label->setGeometry(10,35,85,20);
   label->setAlignment(AlignRight|AlignVCenter);
@@ -126,6 +155,8 @@ RDCutDialog::RDCutDialog(QString *cutname,QString *filter,QString *group,
   cut_cart_list->setItemMargin(5);
   connect(cut_cart_list,SIGNAL(selectionChanged()),
 	  this,SLOT(selectionChangedData()));
+  connect(cut_cart_list,SIGNAL(clicked(QListViewItem *)),
+	  this,SLOT(cartClickedData(QListViewItem *)));
   label=new QLabel(cut_cart_list,tr("Carts"),this,"cut_cart_label");
   label->setGeometry(15,70,100,20);
   label->setFont(label_font);
@@ -186,23 +217,39 @@ RDCutDialog::RDCutDialog(QString *cutname,QString *filter,QString *group,
   //
   // OK Button
   //
-  button=new QPushButton(tr("&OK"),this,"ok_button");
-  button->setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
-  button->setFont(label_font);
-  button->setDefault(true);
-  connect(button,SIGNAL(clicked()),this,SLOT(okData()));
+  cut_ok_button=new QPushButton(tr("&OK"),this,"ok_button");
+  cut_ok_button->
+    setGeometry(sizeHint().width()-180,sizeHint().height()-60,80,50);
+  cut_ok_button->setFont(label_font);
+  cut_ok_button->setDefault(true);
+  connect(cut_ok_button,SIGNAL(clicked()),this,SLOT(okData()));
 
   //
   // Cancel Button
   //
-  button=new QPushButton(tr("&Cancel"),this,"cancel_button");
-  button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
-  button->setFont(label_font);
-  connect(button,SIGNAL(clicked()),this,SLOT(cancelData()));
+  cut_cancel_button=new QPushButton(tr("&Cancel"),this,"cancel_button");
+  cut_cancel_button->
+    setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
+  cut_cancel_button->setFont(label_font);
+  connect(cut_cancel_button,SIGNAL(clicked()),this,SLOT(cancelData()));
 
   //
   // Populate Data
   //
+  if(cut_cutname->isEmpty()) {
+    cut_ok_button->setDisabled(true);
+  }
+  switch(cut_filter_mode) {
+    case RDStation::FilterAsynchronous:
+      cut_search_button->setDefault(true);
+      cut_filter_edit->setGeometry(100,10,sizeHint().width()-250,20);
+      break;
+
+    case RDStation::FilterSynchronous:
+      cut_ok_button->setDefault(true);
+      cut_search_button->hide();
+      cut_filter_edit->setGeometry(100,10,sizeHint().width()-180,20);
+  }
   BuildGroupList();
   cut_filter_edit->setText(*cut_filter);
   RefreshCarts();
@@ -233,14 +280,15 @@ QSizePolicy RDCutDialog::sizePolicy() const
 
 void RDCutDialog::filterChangedData(const QString &str)
 {
-  if(str.isEmpty()) {
-    cut_clear_button->setDisabled(true);
+  cut_search_button->setEnabled(true);
+  switch(cut_filter_mode) {
+    case RDStation::FilterSynchronous:
+      searchButtonData();
+      break;
+
+    case RDStation::FilterAsynchronous:
+      break;
   }
-  else {
-    cut_clear_button->setEnabled(true);
-  }
-  RefreshCarts();
-  RefreshCuts();
 }
 
 
@@ -253,8 +301,13 @@ void RDCutDialog::clearData()
 
 void RDCutDialog::groupActivatedData(const QString &str)
 {
-  RefreshCarts();
-  RefreshCuts();
+  filterChangedData("");
+}
+
+
+void RDCutDialog::cartClickedData(QListViewItem *)
+{
+  cut_ok_button->setEnabled(true);
 }
 
 
@@ -267,6 +320,19 @@ void RDCutDialog::selectionChangedData()
 }
 
 
+void RDCutDialog::searchButtonData()
+{
+  if(cut_filter_edit->text().isEmpty()) {
+    cut_clear_button->setDisabled(true);
+  }
+  else {
+    cut_clear_button->setEnabled(true);
+  }
+  RefreshCarts();
+  RefreshCuts();
+}
+
+
 void RDCutDialog::clearButtonData()
 {
   RDListViewItem *item=(RDListViewItem *)cut_cart_list->selectedItem();
@@ -283,7 +349,7 @@ void RDCutDialog::addButtonData()
   RDCart::Type cart_type=RDCart::Audio;
   QString cart_title;
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   int cart_num=-1;
 
   RDAddCart *add_cart=new RDAddCart(&cart_group,&cart_type,&cart_title,
@@ -297,12 +363,12 @@ void RDCutDialog::addButtonData()
 			cart_num,cart_type,
 			(const char *)cart_group,
 			(const char *)cart_title);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("insert into CUTS set CUT_NAME=\"%06d_001\",\
                          CART_NUMBER=%d,DESCRIPTION=\"Cut 001\"",
 			cart_num,cart_num);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 
   RDListViewItem *item=new RDListViewItem(cut_cart_list);
@@ -360,7 +426,7 @@ void RDCutDialog::closeEvent(QCloseEvent *e)
 void RDCutDialog::RefreshCarts()
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   RDListViewItem *l;
   QString group=cut_group_box->currentText();
 
@@ -378,7 +444,11 @@ void RDCutDialog::RefreshCarts()
   if(cut_exclude_tracks) {
     sql+="&&(CART.OWNER is null)";
   }
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
+  int step=0;
+  int count=0;
+  cut_progress_dialog->setTotalSteps(q->size()/RDCUT_DIALOG_STEP_SIZE);
+  cut_progress_dialog->setProgress(0);
   while(q->next()) {
     l=new RDListViewItem(cut_cart_list);
     l->setPixmap(0,*cut_playout_map);
@@ -387,8 +457,15 @@ void RDCutDialog::RefreshCarts()
     l->setText(2,q->value(1).toString());     // Title
     l->setText(3,q->value(2).toString());     // Group
     l->setTextColor(3,q->value(3).toString(),QFont::Bold);
+    if(count++>RDCUT_DIALOG_STEP_SIZE) {
+      cut_progress_dialog->setProgress(++step);
+      count=0;
+      qApp->eventLoop()->processEvents(QEventLoop::ExcludeUserInput);
+    }
   }
+  cut_progress_dialog->reset();
   delete q;
+  cut_search_button->setDisabled(true);
 }
 
 
@@ -397,17 +474,17 @@ void RDCutDialog::RefreshCuts()
 
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QListViewItem *l;
   QListViewItem *cart_item=cut_cart_list->selectedItem();
 
+  cut_cut_list->clear();
   if(cart_item==NULL) {
     return;
   }
-  cut_cut_list->clear();
   sql=QString().sprintf("select DESCRIPTION,CUT_NAME from CUTS where \
 CART_NUMBER=%s",(const char *)cart_item->text(1));
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     l=new QListViewItem(cut_cut_list);
     l->setText(0,q->value(0).toString());     // Description
@@ -438,7 +515,7 @@ void RDCutDialog::SelectCut(QString cutname)
 void RDCutDialog::BuildGroupList()
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   
   cut_group_box->clear();
   cut_group_box->insertItem(tr("ALL"));
@@ -450,7 +527,7 @@ void RDCutDialog::BuildGroupList()
                            where USER_NAME=\"%s\" order by GROUP_NAME",
 			  (const char *)cut_username);
   }
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     cut_group_box->insertItem(q->value(0).toString(),true);
   }
