@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdexport_settings_dialog.cpp,v 1.9 2007/10/18 15:42:13 dmills Exp $
+//      $Id: rdexport_settings_dialog.cpp,v 1.10 2008-09-18 19:02:07 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -54,6 +54,11 @@ RDExportSettingsDialog::RDExportSettingsDialog(RDSettings *settings,
   //
   setCaption(tr("Edit Export Settings"));
 
+  //
+  // Custom Encoders
+  //
+  lib_encoders=new RDEncoderList(station->name());
+
   //
   // Default Format
   //
@@ -162,6 +167,12 @@ RDExportSettingsDialog::RDExportSettingsDialog(RDSettings *settings,
       lib_format_box->setCurrentItem(lib_format_box->count()-1);
     }
   }
+  for(unsigned i=0;i<lib_encoders->encoderQuantity();i++) {
+    lib_format_box->insertItem(lib_encoders->encoder(i)->name());
+    if(settings->format()==lib_encoders->encoder(i)->id()) {
+      lib_format_box->setCurrentItem(lib_format_box->count()-1);
+    }
+  }
   lib_channels_box->insertItem("1");
   lib_channels_box->insertItem("2");
   lib_channels_box->setCurrentItem(lib_settings->channels()-1);
@@ -183,6 +194,7 @@ RDExportSettingsDialog::RDExportSettingsDialog(RDSettings *settings,
 
 RDExportSettingsDialog::~RDExportSettingsDialog()
 {
+  delete lib_encoders;
   delete lib_channels_box;
   delete lib_samprate_box;
   delete lib_bitrate_box;
@@ -238,38 +250,71 @@ void RDExportSettingsDialog::okData()
   lib_settings->setChannels(lib_channels_box->currentItem()+1);
   lib_settings->setSampleRate(lib_samprate_box->currentText().toInt());
   switch(lib_settings->format()) {
-      case RDSettings::Pcm16:
-	lib_settings->setBitRate(0);
+    case RDSettings::Pcm16:
+      lib_settings->setBitRate(0);
+      lib_settings->setQuality(0);
+      break;
+      
+    case RDSettings::MpegL1:
+    case RDSettings::MpegL2:
+    case RDSettings::MpegL3:
+      if (lib_bitrate_box && lib_bitrate_box->currentText()){
+	sscanf(lib_bitrate_box->currentText(),"%d",&rate);
+      }
+      if(rate!=0) {
+	lib_settings->setBitRate(1000*rate);
 	lib_settings->setQuality(0);
-	break;
-
-      case RDSettings::MpegL1:
-      case RDSettings::MpegL2:
-      case RDSettings::MpegL3:
-	if (lib_bitrate_box && lib_bitrate_box->currentText()){
-	  sscanf(lib_bitrate_box->currentText(),"%d",&rate);
-	}
-	if(rate!=0) {
-	  lib_settings->setBitRate(1000*rate);
-	  lib_settings->setQuality(0);
-	}
-	else {
-	  lib_settings->setBitRate(0);
-	  lib_quality_spin->setRange(0,9);
-	  lib_settings->setQuality(lib_quality_spin->value());
-	}
-	break;
-
-      case RDSettings::Flac:
+      }
+      else {
 	lib_settings->setBitRate(0);
-	lib_settings->setQuality(0);
-	break;
-
-      case RDSettings::OggVorbis:
-	lib_settings->setBitRate(0);
-	lib_quality_spin->setRange(-1,10);
+	lib_quality_spin->setRange(0,9);
 	lib_settings->setQuality(lib_quality_spin->value());
-	break;
+      }
+      break;
+      
+    case RDSettings::Flac:
+      lib_settings->setBitRate(0);
+      lib_settings->setQuality(0);
+      break;
+      
+    case RDSettings::OggVorbis:
+      lib_settings->setBitRate(0);
+      lib_quality_spin->setRange(-1,10);
+      lib_settings->setQuality(lib_quality_spin->value());
+      break;
+      
+    default:   // Custom format
+      for(unsigned i=0;i<lib_encoders->encoderQuantity();i++) {
+	if(lib_encoders->encoder(i)->id()==lib_settings->format()) {
+	  lib_settings->setFormatName(lib_encoders->encoder(i)->name());
+	  lib_settings->
+	    setCustomCommandLine(lib_encoders->encoder(i)->commandLine());
+	}
+      }
+      if(lib_channels_box->isEnabled()) {
+	lib_settings->setChannels(lib_channels_box->currentText().toUInt());
+      }
+      else {
+	lib_settings->setChannels(0);
+      }
+      if(lib_samprate_box->isEnabled()) {
+	lib_settings->setSampleRate(lib_samprate_box->currentText().toUInt());
+      }
+      else {
+	lib_settings->setSampleRate(0);
+      }
+      if(lib_bitrate_box->isEnabled()) {
+	sscanf(lib_bitrate_box->currentText(),"%d",&rate);
+      }
+      if(rate!=0) {
+	lib_settings->setBitRate(1000*rate);
+	lib_settings->setQuality(0);
+      }
+      else {
+	lib_settings->setBitRate(0);
+      }
+      
+      break;
   }
   done(0);
 }
@@ -281,12 +326,24 @@ void RDExportSettingsDialog::cancelData()
 }
 
 
-void RDExportSettingsDialog::ShowBitRates(RDSettings::Format fmt,int samprate,
+void RDExportSettingsDialog::ShowBitRates(RDSettings::Format fmt,
+					  int new_samprate,
 					  int bitrate,int qual)
 {
+  RDEncoder *encoder;
+
+  int samprate=lib_samprate_box->currentText().toInt();
+  int channels=lib_channels_box->currentText().toInt();
+  lib_channels_box->clear();
+  lib_samprate_box->clear();
   lib_bitrate_box->clear();
   switch(fmt) {
       case RDSettings::Pcm16:  // PCM16
+	lib_channels_box->insertItem("1");
+	lib_channels_box->insertItem("2");
+	lib_samprate_box->insertItem("32000");
+	lib_samprate_box->insertItem("44100");
+	lib_samprate_box->insertItem("48000");
 	lib_bitrate_box->setDisabled(true);
 	lib_bitrate_label->setDisabled(true);
 	lib_quality_spin->setDisabled(true);
@@ -294,6 +351,13 @@ void RDExportSettingsDialog::ShowBitRates(RDSettings::Format fmt,int samprate,
 	break;
 
       case RDSettings::MpegL1:  // MPEG-1 Layer 1
+	lib_channels_box->insertItem("1");
+	lib_channels_box->insertItem("2");
+	lib_samprate_box->insertItem("16000");
+	lib_samprate_box->insertItem("22050");
+	lib_samprate_box->insertItem("32000");
+	lib_samprate_box->insertItem("44100");
+	lib_samprate_box->insertItem("48000");
 	lib_bitrate_box->setEnabled(true);
 	lib_bitrate_label->setEnabled(true);
 	lib_bitrate_box->insertItem(tr("32 kbps"));
@@ -407,6 +471,13 @@ void RDExportSettingsDialog::ShowBitRates(RDSettings::Format fmt,int samprate,
 	break;
 
       case RDSettings::MpegL2:  // MPEG-1 Layer 2
+	lib_channels_box->insertItem("1");
+	lib_channels_box->insertItem("2");
+	lib_samprate_box->insertItem("16000");
+	lib_samprate_box->insertItem("22050");
+	lib_samprate_box->insertItem("32000");
+	lib_samprate_box->insertItem("44100");
+	lib_samprate_box->insertItem("48000");
 	lib_bitrate_box->setEnabled(true);
 	lib_bitrate_label->setEnabled(true);
 	lib_bitrate_box->insertItem(tr("32 kbps"));
@@ -517,6 +588,11 @@ void RDExportSettingsDialog::ShowBitRates(RDSettings::Format fmt,int samprate,
 	break;
 
       case RDSettings::MpegL3:  // MPEG-1 Layer 3
+	lib_channels_box->insertItem("1");
+	lib_channels_box->insertItem("2");
+	lib_samprate_box->insertItem("32000");
+	lib_samprate_box->insertItem("44100");
+	lib_samprate_box->insertItem("48000");
 	lib_bitrate_box->setEnabled(true);
 	lib_bitrate_label->setEnabled(true);
 	switch(samprate) {
@@ -750,6 +826,11 @@ void RDExportSettingsDialog::ShowBitRates(RDSettings::Format fmt,int samprate,
 	break;
 
       case RDSettings::Flac:
+	lib_channels_box->insertItem("1");
+	lib_channels_box->insertItem("2");
+	lib_samprate_box->insertItem("32000");
+	lib_samprate_box->insertItem("44100");
+	lib_samprate_box->insertItem("48000");
 	lib_bitrate_box->setDisabled(true);
 	lib_bitrate_label->setDisabled(true);
 	lib_quality_spin->setDisabled(true);
@@ -757,6 +838,11 @@ void RDExportSettingsDialog::ShowBitRates(RDSettings::Format fmt,int samprate,
 	break;
 
       case RDSettings::OggVorbis:
+	lib_channels_box->insertItem("1");
+	lib_channels_box->insertItem("2");
+	lib_samprate_box->insertItem("32000");
+	lib_samprate_box->insertItem("44100");
+	lib_samprate_box->insertItem("48000");
 	lib_bitrate_box->setDisabled(true);
 	lib_bitrate_label->setDisabled(true);
 	lib_quality_spin->setEnabled(true);
@@ -764,6 +850,61 @@ void RDExportSettingsDialog::ShowBitRates(RDSettings::Format fmt,int samprate,
 	lib_quality_spin->setRange(-1,10);
 	lib_quality_spin->setValue(qual);
 	break;
+
+    default:   // Custom format
+      lib_channels_box->clear();
+      lib_samprate_box->clear();
+      lib_bitrate_box->clear();
+      for(unsigned i=0;i<lib_encoders->encoderQuantity();i++) {
+	encoder=lib_encoders->encoder(i);
+	if(encoder->id()==fmt) {
+	  if(encoder->allowedChannelsQuantity()==0) {
+	    lib_channels_box->setDisabled(true);
+	  }
+	  else {
+	    lib_channels_box->setEnabled(true);
+	    for(unsigned j=0;j<encoder->allowedChannelsQuantity();j++) {
+	      lib_channels_box->
+		insertItem(QString().sprintf("%d",encoder->allowedChannel(j)));
+	    }
+	  }
+	  if(encoder->allowedSampleratesQuantity()==0) {
+	    lib_samprate_box->setDisabled(true);
+	  }
+	  else {
+	    lib_samprate_box->setEnabled(true);
+	    for(unsigned j=0;j<encoder->allowedSampleratesQuantity();j++) {
+	      lib_samprate_box->
+		insertItem(QString().sprintf("%d",
+					     encoder->allowedSamplerate(j)));
+	    }
+	  }
+	  if(encoder->allowedBitratesQuantity()==0) {
+	    lib_bitrate_box->setDisabled(true);
+	  }
+	  else {
+	    lib_bitrate_box->setEnabled(true);
+	    for(unsigned j=0;j<encoder->allowedBitratesQuantity();j++) {
+	      lib_bitrate_box->
+		insertItem(QString().sprintf("%d kbps",
+					     encoder->allowedBitrate(j)));
+	    }
+	  }
+	}
+      }
+      break;
+  }
+  SetCurrentItem(lib_channels_box,channels);
+  SetCurrentItem(lib_samprate_box,samprate);
+}
+
+
+void RDExportSettingsDialog::SetCurrentItem(QComboBox *box,int value)
+{
+  for(int i=0;i<box->count();i++) {
+    if(box->text(i).toInt()==value) {
+      box->setCurrentItem(i);
+    }
   }
 }
 
@@ -785,6 +926,11 @@ RDSettings::Format RDExportSettingsDialog::GetFormat(QString str)
   if(str==tr("OggVorbis")) {
     return RDSettings::OggVorbis;
   }
+  for(unsigned i=0;i<lib_encoders->encoderQuantity();i++) {
+    if(str==lib_encoders->encoder(i)->name()) {
+      return (RDSettings::Format)lib_encoders->encoder(i)->id();
+    }
+  }
   return RDSettings::Pcm16;
 }
 
