@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdgroup_list.cpp,v 1.6 2007/10/04 20:53:28 dmills Exp $
+//      $Id: rdgroup_list.cpp,v 1.7 2008-04-01 20:51:39 grauf Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,31 +30,6 @@ RDGroupList::RDGroupList()
 }
 
 
-void RDGroupList::loadStation(QString stationname)
-{
-  QString sql;
-  RDSqlQuery *q;
-
-  clear();
-  sql=QString().sprintf("select SERVICE_NAME from SERVICE_PERMS\
-                         where STATION_NAME=\"%s\"",
-			(const char *)stationname);
-  q=new RDSqlQuery(sql);
-  sql=QString().sprintf("select GROUP_NAME from AUDIO_PERMS where ");
-  while(q->next()) {
-    sql+=QString().sprintf("(SERVICE_NAME=\"%s\")||",
-			   (const char *)q->value(0).toString());
-  }
-  delete q;
-  sql=sql.left(sql.length()-2);
-  q=new RDSqlQuery(sql);
-  while(q->next()) {
-    list_groups.push_back(QString(q->value(0).toString()));
-  }
-  delete q;
-}
-
-
 void RDGroupList::loadSvc(QString svcname)
 {
   QString sql;
