@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdsound_panel.cpp,v 1.43 2007/09/14 14:06:24 fredg Exp $
+//      $Id: rdsound_panel.cpp,v 1.53 2008-07-15 18:29:01 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,25 +21,28 @@
 //
 
 #include <qsignalmapper.h>
-
+#include <rddb.h>
 #include <rdlog_line.h>
 #include <rdsound_panel.h>
 #include <rdbutton_dialog.h>
 #include <rdmacro.h>
 #include <rdcut.h>
 #include <rdedit_panel_name.h>
+#include <rdescape_string.h>
 
 
 RDSoundPanel::RDSoundPanel(int cols,int rows,int station_panels,
 			   int user_panels,bool flash,
 			   const QString &label_template,bool extended,
 			   RDEventPlayer *player,RDRipc *ripc,RDCae *cae,
-			   RDStation *station,QWidget *parent,const char *name)
+			   RDStation *station,RDCartDialog *cart_dialog,
+			   QWidget *parent,const char *name)
   : QWidget(parent,name)
 {
   panel_playmode_box=NULL;
   panel_button_columns=cols;
   panel_button_rows=rows;
+  panel_cue_port=-1;
   if(extended) {
     panel_tablename="EXTENDED_PANELS";
     panel_name_tablename="EXTENDED_PANEL_NAMES";
@@ -75,6 +78,7 @@ RDSoundPanel::RDSoundPanel(int cols,int rows,int station_panels,
     panel_card[i]=-1;
     panel_port[i]=-1;
   }
+  panel_cart_dialog=cart_dialog;
 
   //
   // Create Fonts
@@ -182,7 +186,8 @@ RDSoundPanel::RDSoundPanel(int cols,int rows,int station_panels,
   //
   panel_button_dialog=
     new RDButtonDialog(panel_station->name(),panel_label_template,
-		       this,"panel_button_dialog");
+		       panel_cart_dialog,panel_svcname,this,
+		       "panel_button_dialog");
 
   //
   // CAE Setup
@@ -200,7 +205,7 @@ RDSoundPanel::RDSoundPanel(int cols,int rows,int station_panels,
 			(const char *)panel_name_tablename,
 			RDAirPlayConf::StationPanel,
 			(const char *)panel_station->name());
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   q->first();
   for(int i=0;i<panel_station_panels;i++) {
     if(q->isValid()&&(q->value(0).toInt()==i)) {
@@ -497,7 +502,7 @@ void RDSoundPanel::changeUser()
 			(const char *)panel_name_tablename,
 			RDAirPlayConf::UserPanel,
 			(const char *)panel_user->name());
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   q->first();
   for(int i=0;i<panel_user_panels;i++) {
     if(q->isValid()&&(q->value(0).toInt()==i)) {
@@ -741,7 +746,7 @@ void RDSoundPanel::timescalingSupportedData(int card,bool state)
 void RDSoundPanel::panelSetupData()
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   int cutpt=panel_selector_box->currentText().find(" ");
   if(panel_selector_box->currentText().left(5)==tr("Panel")) {
     cutpt=-1;
@@ -758,14 +763,14 @@ void RDSoundPanel::panelSetupData()
 			  (const char *)panel_name_tablename,
 			  panel_type,(const char *)PanelOwner(panel_type),
 			  panel_number);
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     delete q;
     sql=QString().sprintf("insert into %s set TYPE=%d,OWNER=\"%s\",\
                            PANEL_NO=%d,NAME=\"%s\"",
 			  (const char *)panel_name_tablename,panel_type,
 			  (const char *)PanelOwner(panel_type),panel_number,
-			  (const char *)panel_name);
-    q=new QSqlQuery(sql);
+			  (const char *)RDEscapeString(panel_name));
+    q=new RDSqlQuery(sql);
     delete q;
   }
   delete edn;
@@ -778,27 +783,26 @@ void RDSoundPanel::PlayButton(RDAirPlayConf::PanelType type,int panel,
 {
   int edit_row=row;
   int edit_col=col;
-
+  
   for(int i=0;i<panel_button_columns;i++) {
-	  for(int j=0;j<panel_button_rows;j++) {
+    for(int j=0;j<panel_button_rows;j++) {
       if(panel_buttons[PanelOffset(type,panel)].
-              panelButton(j,i)->cart()>0 && 
+	 panelButton(j,i)->cart()>0 && 
          panel_buttons[PanelOffset(type,panel)].
-              panelButton(j,i)->state()==false) {
+	 panelButton(j,i)->state()==false) {
         if(edit_col==-1 || col==i) {
-           edit_col=i;
-           if(edit_row==-1) {
-             edit_row=j;
-             } 
-           }
-        }
+	  edit_col=i;
+	  if(edit_row==-1) {
+	    edit_row=j;
+	  } 
+	}
       }
     }
+  }
   if(edit_row==-1 || edit_col==-1) {
     return;
-    }
-    
-    
+  }
+  
   RDPanelButton *button=
     panel_buttons[PanelOffset(type,panel)].panelButton(edit_row,edit_col);
   RDPlayDeck *deck=button->playDeck();
@@ -948,7 +952,7 @@ void RDSoundPanel::PlayMacro(RDPanelButton *button,RDCart *cart)
   rml.setArgQuantity(1);
   rml.setArg(0,cart->number());
   panel_ripc->sendRml(&rml);
-  if(!panel_logname.isEmpty()) {
+  if(!panel_svcname.isEmpty()) {
     LogTrafficMacro(button);
   }
   if(button->pauseWhenFinished() && panel_pause_enabled) {
@@ -1143,7 +1147,7 @@ void RDSoundPanel::LoadPanel(RDAirPlayConf::PanelType type,int panel)
 				panel,
 				(const char *)panel_tablename,
 				(const char *)panel_tablename);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   while(q->next()) {
     if(panel_buttons[offset].panelButton(q->value(0).toInt(),
 	      q->value(1).toInt())->playDeck()==NULL) {
@@ -1196,7 +1200,8 @@ void RDSoundPanel::SaveButton(RDAirPlayConf::PanelType type,
 			    int panel,int row,int col)
 {
   QString sql;
-  QSqlQuery *q;
+  QString sql1;
+  RDSqlQuery *q;
   QString owner;
   int offset=0;
 
@@ -1223,29 +1228,30 @@ void RDSoundPanel::SaveButton(RDAirPlayConf::PanelType type,
 			panel,
 			row,
 			col);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->size()>0) {
     //
     // If so, update the record
     //
     delete q;
-    sql=QString().sprintf("update %s set LABEL=\"%s\",\
+    sql1=QString().sprintf("update %s set LABEL=\"%s\",\
     CART=%d,DEFAULT_COLOR=\"%s\" where (TYPE=%d)&&(OWNER=\"%s\")&&\
     (PANEL_NO=%d)&&(ROW_NO=%d)&&(COLUMN_NO=%d)",
-			  (const char *)panel_tablename,
-			  (const char *)panel_buttons[offset].
-			  panelButton(row,col)->text().utf8(),
-			  panel_buttons[PanelOffset(panel_type,panel_number)].
-			  panelButton(row,col)->cart(),
-			  (const char *)panel_buttons[offset].
-			  panelButton(row,col)->defaultColor().
-			  name(),
-			  type,
-			  (const char *)owner,
-			  panel,
-			  row,
-			  col);
-    q=new QSqlQuery(sql);
+			   (const char *)panel_tablename,
+			   (const char *)RDEscapeString(panel_buttons[offset].
+							panelButton(row,col)->
+							text().utf8()),
+			   panel_buttons[PanelOffset(panel_type,panel_number)].
+			   panelButton(row,col)->cart(),
+			   (const char *)panel_buttons[offset].
+			   panelButton(row,col)->defaultColor().
+			   name(),
+			   type,
+			   (const char *)RDEscapeString(owner),
+			   panel,
+			   row,
+			   col);
+    q=new RDSqlQuery(sql1);
     if(q->isActive()) {
       delete q;
       return;
@@ -1258,25 +1264,25 @@ void RDSoundPanel::SaveButton(RDAirPlayConf::PanelType type,
     //
     // Otherwise, insert a new one
     //
-    sql=QString().sprintf("insert into %s (TYPE,OWNER,\
+    sql1=QString().sprintf("insert into %s (TYPE,OWNER,\
     PANEL_NO,ROW_NO,COLUMN_NO,LABEL,CART,DEFAULT_COLOR)\
     values (%d,\"%s\",%d,%d,%d,\"%s\",%d,\"%s\")",
-			  (const char *)panel_tablename,
-			  type,
-			  (const char *)owner,
-			  panel,
-			  row,
-			  col,
-			  (const char *)panel_buttons[offset].
-			  panelButton(row,col)->text().utf8(),
-			  panel_buttons[PanelOffset(panel_type,panel_number)].
-			  panelButton(row,col)->cart(),
-			  (const char *)panel_buttons[offset].
-			  panelButton(row,col)->
-			  defaultColor().name());
-    q=new QSqlQuery(sql);
+			   (const char *)panel_tablename,
+			   type,
+			   (const char *)RDEscapeString(owner),
+			   panel,
+			   row,
+			   col,
+			   (const char *)RDEscapeString(panel_buttons[offset].
+							panelButton(row,col)->
+							text().utf8()),
+			   panel_buttons[PanelOffset(panel_type,panel_number)].
+			   panelButton(row,col)->cart(),
+			   (const char *)panel_buttons[offset].
+			   panelButton(row,col)->
+			   defaultColor().name());
+    q=new RDSqlQuery(sql1);
     delete q;
-    
   }
 }
 
@@ -1337,8 +1343,12 @@ void RDSoundPanel::LogPlayEvent(unsigned cartnum,int cutnum)
 
 void RDSoundPanel::LogTraffic(RDPanelButton *button)
 {
+  if(panel_svcname.isEmpty()) {
+    return;
+  }
+
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QDateTime datetime(QDate::currentDate(),QTime::currentTime());
 
   sql=QString().sprintf("select CART.TITLE,CART.ARTIST,CART.PUBLISHER,\
@@ -1348,7 +1358,7 @@ void RDSoundPanel::LogTraffic(RDPanelButton *button)
                          on CART.NUMBER=CUTS.CART_NUMBER \
                          where CUTS.CUT_NAME=\"%s\"",
 			(const char *)button->cutName());
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     sql=QString().sprintf("insert into `%s_SRT` set\
                          LENGTH=%d,CART_NUMBER=%u,\
@@ -1361,7 +1371,7 @@ void RDSoundPanel::LogTraffic(RDPanelButton *button)
 			  (const char *)panel_svcname,
 			  button->startTime().msecsTo(datetime.time()),
 			  button->cart(),
-			  (const char *)panel_station->name(),
+			  (const char *)RDEscapeString(panel_station->name()),
 			  (const char *)datetime.toString("yyyy-MM-dd"),
 			  (const char *)button->startTime().
 			  toString("hh:mm:ss"),
@@ -1369,17 +1379,17 @@ void RDSoundPanel::LogTraffic(RDPanelButton *button)
 			  RDLogLine::SoundPanel,
 			  RDLogLine::SoundPanel,
 			  button->cutName().right(3).toInt(),
-			  (const char *)q->value(0).toString(),
-			  (const char *)q->value(1).toString(),
-			  (const char *)q->value(2).toString(),
-			  (const char *)q->value(3).toString(),
+			  (const char *)RDEscapeString(q->value(0).toString()),
+			  (const char *)RDEscapeString(q->value(1).toString()),
+			  (const char *)RDEscapeString(q->value(2).toString()),
+			  (const char *)RDEscapeString(q->value(3).toString()),
 			  q->value(4).toInt(),
 			  (const char *)q->value(5).toString(),
 			  button->startSource(),
-			  (const char *)q->value(6).toString(),
-			  (const char *)q->value(7).toString());
+			  (const char *)RDEscapeString(q->value(6).toString()),
+			  (const char *)RDEscapeString(q->value(7).toString()));
     delete q;
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
   }
   delete q;
 }
@@ -1388,22 +1398,44 @@ void RDSoundPanel::LogTraffic(RDPanelButton *button)
 void RDSoundPanel::LogTrafficMacro(RDPanelButton *button)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QDateTime datetime(QDate::currentDate(),QTime::currentTime());
 
-  sql=QString().sprintf("insert into %s_REC set\
-                         LENGTH=0,CART_NUMBER=%d,STATION_NAME=\"%s\",\
-                         EVENT_DATETIME=\"%s %s\",EVENT_TYPE=%d,\
-                         PLAY_SOURCE=%d",
-			(const char *)panel_logname,
-			button->cart(),
-			(const char *)panel_station->name(),
-			(const char *)datetime.toString("yyyy-MM-dd hh:mm:ss"),
-			(const char *)button->startTime().toString("hh:mm:ss"),
-			RDAirPlayConf::TrafficMacro,
-			RDLogLine::SoundPanel);
-  q=new QSqlQuery(sql);
-  delete q;
+  sql=QString().sprintf("select TITLE,ARTIST,PUBLISHER,\
+                         COMPOSER,USAGE_CODE,FORCED_LENGTH,\
+                         ALBUM,LABEL from CART where NUMBER=%u",
+			(const char *)button->cart());
+  q=new RDSqlQuery(sql);
+  if(q->first()) {
+    sql=QString().sprintf("insert into `%s_SRT` set\
+                         LENGTH=%d,CART_NUMBER=%u,\
+                         STATION_NAME=\"%s\",EVENT_DATETIME=\"%s\",\
+                         EVENT_TYPE=%d,EVENT_SOURCE=%d,PLAY_SOURCE=%d,\
+                         TITLE=\"%s\",ARTIST=\"%s\",\
+                         PUBLISHER=\"%s\",COMPOSER=\"%s\",USAGE_CODE=%d,\
+                         START_SOURCE=%d,ALBUM=\"%s\",\
+                         LABEL=\"%s\"",
+			  (const char *)panel_svcname,
+			  q->value(5).toUInt(),
+			  button->cart(),
+			  (const char *)RDEscapeString(panel_station->name()),
+			  (const char *)datetime.
+			  toString("yyyy-MM-dd hh:mm:ss"),
+			  RDAirPlayConf::TrafficMacro,
+			  RDLogLine::SoundPanel,
+			  RDLogLine::SoundPanel,
+			  (const char *)RDEscapeString(q->value(0).toString()),
+			  (const char *)RDEscapeString(q->value(1).toString()),
+			  (const char *)RDEscapeString(q->value(2).toString()),
+			  (const char *)RDEscapeString(q->value(3).toString()),
+			  q->value(4).toInt(),
+			  button->startSource(),
+			  (const char *)RDEscapeString(q->value(6).toString()),
+			  (const char *)RDEscapeString(q->value(7).toString()));
+    delete q;
+    q=new RDSqlQuery(sql);
+    delete q;
+  }
 }
 
 
