@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdttyout.h,v 1.3 2007/02/14 21:48:41 fredg Exp $
+//      $Id: rdttyout.h,v 1.5 2008-08-04 19:05:34 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -22,12 +22,13 @@
 
 #include <qstring.h>
 #include <qsqldatabase.h>
-#include <rttydevice.h>
+
+#include <rdttydevice.h>
 
 #ifndef RDTTYOUT_H
 #define RDTTYOUT_H
 
-bool RDTtyOut(QString station,unsigned port_id,QString string);
+bool RDTtyOut(const QString &station,unsigned port_id,const QString &string);
 
 
 #endif 
