@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rduser.cpp,v 1.18 2007/09/14 14:06:24 fredg Exp $
+//      $Id: rduser.cpp,v 1.23 2008-08-04 19:05:34 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -21,9 +21,9 @@
 //
 
 #include <rdconf.h>
-
 #include <rduser.h>
-
+#include <rddb.h>
+#include <rdescape_string.h>
 
 //
 // Global Classes
@@ -46,36 +46,42 @@ bool RDUser::exists() const
 }
 
 
-bool RDUser::authenticated() const
+bool RDUser::authenticated(bool webuser) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   //
   // Try the "new" syntax first
   //
-  sql=QString().sprintf("select LOGIN_NAME from USERS where LOGIN_NAME=\"%s\" \
+  sql=QString().sprintf("select LOGIN_NAME,ENABLE_WEB from USERS \
+                         where LOGIN_NAME=\"%s\" \
                          && PASSWORD=OLD_PASSWORD(\"%s\")",
 			(const char *)user_name,
 			(const char *)user_password);
-  q=new QSqlQuery(sql);
-  if(q->size()>0) {
+  q=new RDSqlQuery(sql);
+  if(q->first()) {
+    bool ret=RDBool(q->value(1).toString())||
+      ((!RDBool(q->value(1).toString()))&&(!webuser));
     delete q;
-    return true;
+    return ret;
   }
   delete q;
 
   //
   // Then try the "old" syntax
   //
-  sql=QString().sprintf("select LOGIN_NAME from USERS where LOGIN_NAME=\"%s\" \
+  sql=QString().sprintf("select LOGIN_NAME,ENABLE_WEB from USERS \
+                         where LOGIN_NAME=\"%s\" \
                          && PASSWORD=PASSWORD(\"%s\")",
 			(const char *)user_name,
 			(const char *)user_password);
-  q=new QSqlQuery(sql);
-  if(q->size()>0) {
+  q=new RDSqlQuery(sql);
+  if(q->first()) {
+    bool ret=RDBool(q->value(1).toString())||
+      ((!RDBool(q->value(1).toString()))&&(!webuser));
     delete q;
-    return true;
+    return ret;
   }
   delete q;
 
@@ -83,16 +89,16 @@ bool RDUser::authenticated() const
 }
 
 
-bool RDUser::checkPassword(const QString &password)
+bool RDUser::checkPassword(const QString &password,bool webuser)
 {
   user_password=password;
-  return authenticated();
+  return authenticated(webuser);
 }
 
 
 void RDUser::setPassword(const QString &password)
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   //
@@ -102,7 +108,7 @@ void RDUser::setPassword(const QString &password)
                          where LOGIN_NAME=\"%s\"",
 			(const char *)password,
 			(const char *)user_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(!q->isActive()) {
     delete q;
     //
@@ -112,13 +118,26 @@ void RDUser::setPassword(const QString &password)
                            WHERE LOGIN_NAME=\"%s\"",
 			  (const char *)password,
 			  (const char *)user_name);
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
   }
   delete q;
   user_password=password;
 }
 
 
+bool RDUser::enableWeb() const
+{
+  return RDBool(RDGetSqlValue("USERS","LOGIN_NAME",user_name,"ENABLE_WEB").
+	       toString());
+}
+
+
+void RDUser::setEnableWeb(bool state) const
+{
+  SetRow("ENABLE_WEB",RDYesNo(state));
+}
+
+
 QString RDUser::fullName() const
 {
   return RDGetSqlValue("USERS","LOGIN_NAME",user_name,"FULL_NAME").toString();
@@ -145,13 +164,14 @@ void RDUser::setDescription(const QString &desc) const
 
 QString RDUser::phone() const
 {
-  return RDGetSqlValue("USERS","LOGIN_NAME",user_name,"PHONE").toString();
+  return RDGetSqlValue("USERS","LOGIN_NAME",user_name,"PHONE_NUMBER").
+    toString();
 }
 
 
 void RDUser::setPhone(const QString &phone) const
 {
-  SetRow("PHONE",phone);
+  SetRow("PHONE_NUMBER",phone);
 }
 
 
@@ -363,16 +383,101 @@ void RDUser::setEditCatches(bool priv) const
 }
 
 
+bool RDUser::addPodcast() const
+{
+  return RDBool(RDGetSqlValue("USERS","LOGIN_NAME",user_name,
+			    "ADD_PODCAST_PRIV").toString());
+}
+
+
+void RDUser::setAddPodcast(bool priv) const
+{
+  SetRow("ADD_PODCAST_PRIV",priv);
+}
+
+
+bool RDUser::editPodcast() const
+{
+  return RDBool(RDGetSqlValue("USERS","LOGIN_NAME",user_name,
+			    "EDIT_PODCAST_PRIV").toString());
+}
+
+
+void RDUser::setEditPodcast(bool priv) const
+{
+  SetRow("EDIT_PODCAST_PRIV",priv);
+}
+
+
+bool RDUser::deletePodcast() const
+{
+  return RDBool(RDGetSqlValue("USERS","LOGIN_NAME",user_name,
+			    "DELETE_PODCAST_PRIV").toString());
+}
+
+
+void RDUser::setDeletePodcast(bool priv) const
+{
+  SetRow("DELETE_PODCAST_PRIV",priv);
+}
+
+
+QString RDUser::serviceCheckDefault(QString serv) const
+{
+  bool match_flag = false;
+  QStringList services_list = services();
+
+  for ( QStringList::Iterator it = services_list.begin(); 
+        it != services_list.end(); ++it ) {
+    if (serv.compare(*it) == 0) {
+      match_flag = true;
+      break;
+    }
+  }
+
+  if (match_flag)
+    return serv;
+  else
+    return QString("");
+}
+
+
+QStringList RDUser::services() const
+{
+  RDSqlQuery *q;
+  QString sql;
+  QStringList services_list;
+
+  if (adminConfig()) {
+    sql=QString().sprintf("SELECT NAME FROM SERVICES" );
+  } else {
+    sql=QString().sprintf("SELECT DISTINCT SERVICE_NAME \
+                            FROM USER_PERMS, AUDIO_PERMS \
+                            WHERE USER_PERMS.USER_NAME='%s' \
+                             AND USER_PERMS.GROUP_NAME=AUDIO_PERMS.GROUP_NAME;",
+                          (const char *)user_name );
+  }
+  
+  q=new RDSqlQuery(sql);
+  while (q->next() ) {
+    services_list.append( q->value(0).toString() );
+  }
+  delete q;
+
+  return services_list;
+}
+
+
 void RDUser::SetRow(const QString &param,const QString &value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("UPDATE USERS SET %s=\"%s\" WHERE LOGIN_NAME=\"%s\"",
 			(const char *)param,
-			(const char *)value,
+			(const char *)RDEscapeString(value),
 			(const char *)user_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
