@@ -1,10 +1,11 @@
+
 // globals.h
 //
 // Global Variable Declarations for RDAirPlay
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: globals.h,v 1.11 2007/12/31 18:49:09 fredg Exp $
+//      $Id: globals.h,v 1.12 2008-03-28 20:00:07 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,6 +32,7 @@
 #include <rdcae.h>
 #include <rdevent_player.h>
 #include <rdcart_dialog.h>
+#include <rdconfig.h>
 
 //
 // Global Resources
@@ -43,7 +45,8 @@ extern RDRipc *rdripc;
 extern RDCae *rdcae;
 extern RDEventPlayer *rdevent_player;
 extern RDCartDialog *rdcart_dialog;
-extern void LogLine(QString line);
+extern void LogLine(RDConfig::LogPriority prio,const QString &line);
 extern QString logfile;
+extern RDConfig *air_config;
 
 #endif  // GLOBALS_H
