@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: log_play.cpp,v 1.165 2007/06/30 10:03:16 stgabriel Exp $
+//      $Id: log_play.cpp,v 1.188.2.3 2008-11-07 12:58:17 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -26,7 +26,7 @@
 #include <rdmixer.h>
 #include <rddebug.h>
 #include <rdlog.h>
-
+#include <rddb.h>
 #include <log_play.h>
 #include <log_traffic.h>
 #include <globals.h>
@@ -44,6 +44,8 @@ LogPlay::LogPlay(RDCae *cae,int id,QSocketDevice *nn_sock,QString logname,
   play_onair_flag=false;
   play_segue_length=rdairplay_conf->segueLength()+1;
   play_trans_length=rdairplay_conf->transLength()+1;
+  play_duck_volume_port1=0;
+  play_duck_volume_port2=0;
   play_start_next=false;
   play_running=false;
   play_next_line=0;
@@ -53,6 +55,7 @@ LogPlay::LogPlay(RDCae *cae,int id,QSocketDevice *nn_sock,QString logname,
   play_active_line=-1;
   play_active_trans=RDLogLine::Play;
   play_trans_line=-1;
+  play_grace_line=-1;
   next_channel=0;
   play_nownext_socket=nn_sock;
   play_timescaling_available=false;
@@ -70,6 +73,8 @@ LogPlay::LogPlay(RDCae *cae,int id,QSocketDevice *nn_sock,QString logname,
     play_deck[i]=new RDPlayDeck(play_cae,0,this);
     play_deck_active[i]=false;
   }
+  play_macro_running=false;
+  play_refresh_pending=false;
   play_nownext_string=rdairplay_conf->udpString(id);
   play_nownext_address=rdairplay_conf->udpAddress(id);
   play_nownext_port=rdairplay_conf->udpPort(id);
@@ -97,11 +102,14 @@ LogPlay::LogPlay(RDCae *cae,int id,QSocketDevice *nn_sock,QString logname,
 	  this,SLOT(onairFlagChangedData(bool)));
 
   //
-  // Transition Timer
+  // Transition Timers
   //
   play_trans_timer=new QTimer(this,"play_trans_timer");
   connect(play_trans_timer,SIGNAL(timeout()),
 	  this,SLOT(transTimerData()));
+  play_grace_timer=new QTimer(this,"play_grace_timer");
+  connect(play_grace_timer,SIGNAL(timeout()),
+	  this,SLOT(graceTimerData()));
 
   //
   // Rescan Timer
@@ -205,13 +213,12 @@ void LogPlay::setSegueLength(int len)
 bool LogPlay::play(int line,RDLogLine::StartSource src,
 		   int mport,bool skip_meta)
 {
+  QTime current_time=QTime::currentTime();
   RDLogLine *logline;
-  int lines[TRANSPORT_QUANTITY];
-
   if((logline=logLine(line))==NULL) {
     return false;
   }
-  if((runningEvents(lines)>=LOGPLAY_MAX_PLAYS)&&
+  if((runningEvents(NULL)>=LOGPLAY_MAX_PLAYS)&&
      (logline->status()!=RDLogLine::Paused)) {
     return false;
   }
@@ -239,28 +246,42 @@ bool LogPlay::play(int line,RDLogLine::StartSource src,
       }
     }
   }
-
   //
   // Play it
   //
-  if(!GetNextPlayable(&line,skip_meta)) {
+  if(!GetNextPlayable(&line,skip_meta,true)) {
     return false;
   }
-  if(play_segue_length==0) {
-    return StartEvent(line,RDLogLine::Play,0,src,mport);
-  }
 
-  return StartEvent(line,RDLogLine::Segue,play_segue_length,src,mport);
+  bool ret = false;
+  if(play_segue_length==0) {
+    ret = StartEvent(line,RDLogLine::Play,0,src,mport);
+  } else {
+    ret = StartEvent(line,RDLogLine::Segue,play_segue_length,src,mport);
+  }
+  SetTransTimer(current_time);
+  return ret;
 }
 
 
-bool LogPlay::stop()
+bool LogPlay::stop(bool all,int port,int fade)
 {
+  RDLogLine *logline;
   int lines[TRANSPORT_QUANTITY];
 
   int n=runningEvents(lines);
   for(int i=0;i<n;i++) {
-    stop(lines[i]);
+    if(all || port<1) { 
+      stop(lines[i],fade);
+      }
+    else {
+      logline=logLine(lines[i]);
+      if(logline->cartType()==RDCart::Audio 
+            && (RDPlayDeck *)logline->playDeck()!=NULL
+            && logline->portName().toInt()==port ) {
+         stop(lines[i],fade);
+         }
+      }
   }
   if(n>0) {
     return true;
@@ -269,7 +290,7 @@ bool LogPlay::stop()
 }
 
 
-bool LogPlay::stop(int line)
+bool LogPlay::stop(int line,int fade)
 {
   RDLogLine *logline;
 
@@ -281,7 +302,7 @@ bool LogPlay::stop(int line)
 	if(((RDPlayDeck *)logline->playDeck())==NULL) {
 	  return false;
 	}
-	((RDPlayDeck *)logline->playDeck())->stop();
+	((RDPlayDeck *)logline->playDeck())->stop(fade,RD_FADE_DEPTH);
 	return true;
 	break;
 
@@ -299,7 +320,7 @@ bool LogPlay::stop(int line)
 bool LogPlay::pause(int line)
 {
   RDLogLine *logline;
-
+  
   if((logline=logLine(line))==NULL) {
     return false;
   }
@@ -319,9 +340,33 @@ bool LogPlay::pause(int line)
 }
 
 
+void LogPlay::duckVolume(int level,int fade,int mport)
+{
+  RDLogLine *logline;
+  int lines[TRANSPORT_QUANTITY];
+
+  if(mport==-1 || mport==1) {
+	  play_duck_volume_port1=level;
+  }
+  if(mport==-1 || mport==2) {
+	  play_duck_volume_port2=level;
+  }
+  int n=runningEvents(lines);
+  for(int i=0;i<n;i++) {
+    logline=logLine(lines[i]);
+    if(logline->cartType()==RDCart::Audio 
+          && (RDPlayDeck *)logline->playDeck()!=NULL
+          && ((logline->portName().toInt()==mport) || mport<1) ) {
+	    ((RDPlayDeck *)logline->playDeck())->duckVolume(level,fade);
+       }
+    }
+}
+		
+
+
 void LogPlay::makeNext(int line,bool refresh_status)
 {
-  LogLine(QString().sprintf("LogPlay::makeNext(%d)",line));
+  LogLine(RDConfig::LogDebug,QString().sprintf("LogPlay::makeNext(%d)",line));
   play_next_line=line;
   if(refresh_status) {
     RefreshEvents(line,LOGPLAY_LOOKAHEAD_EVENTS);
@@ -336,6 +381,9 @@ void LogPlay::load()
   int lines[TRANSPORT_QUANTITY];
   int running=0;
 
+  play_duck_volume_port1=0;
+  play_duck_volume_port2=0;
+  
   //
   // Remove All Idle Events
   //
@@ -408,6 +456,18 @@ bool LogPlay::refresh()
   int lines[TRANSPORT_QUANTITY];
   int running;
 
+  if(!play_refreshable) {
+    return false;
+  }
+  if(play_macro_running) {
+    play_refresh_pending=true;
+    return true;
+  }
+  emit refreshStatusChanged(true);
+  if((size()==0)||(play_log==NULL)) {
+    emit refreshStatusChanged(false);
+    return true;
+  }
 
   //
   // Load the Updated Log
@@ -417,7 +477,6 @@ bool LogPlay::refresh()
   e->load();
   play_modified_datetime=play_log->modifiedDatetime();
 
-
   //
   // Get the Next Event
   //
@@ -521,6 +580,8 @@ bool LogPlay::refresh()
     emit refreshabilityChanged(play_refreshable);
   }
 
+  emit refreshStatusChanged(false);
+
   return true;
 }
 
@@ -547,6 +608,8 @@ void LogPlay::clear()
 {
   setLogName("");
   int start_line=0;
+  play_duck_volume_port1=0;
+  play_duck_volume_port2=0;
   while(ClearBlock(start_line++));
   play_svc_name=play_defaultsvc_name;
   play_rescan_pos=0;
@@ -579,10 +642,11 @@ void LogPlay::insert(int line,int cartnum,RDLogLine::TransType next_type,
   int running=runningEvents(lines);
   for(int i=0;i<running;i++) {
     if((logline=logLine(lines[i]))!=NULL) {
-      playdeck=(RDPlayDeck *)logline->playDeck();
-      if((playdeck->id()>=0)&&
-	 (playdeck->id()>=line)) {
-	playdeck->setId(playdeck->id()+1);
+      if((playdeck=(RDPlayDeck *)logline->playDeck())!=NULL) {
+	if((playdeck->id()>=0)&&
+	   (playdeck->id()>=line)) {
+	  playdeck->setId(playdeck->id()+1);
+	}
       }
     }
   }
@@ -631,10 +695,11 @@ void LogPlay::insert(int line,RDLogLine *l,bool update,bool preserv_custom_trans
   int running=runningEvents(lines);
   for(int i=0;i<running;i++) {
     if((logline=logLine(lines[i]))!=NULL) {
-      playdeck=(RDPlayDeck *)logline->playDeck();
-      if((playdeck->id()>=0)&&
-	 (playdeck->id()>=line)) {
-	playdeck->setId(playdeck->id()+1);
+      if((playdeck=(RDPlayDeck *)logline->playDeck())!=NULL) {
+	if((playdeck->id()>=0)&&
+	   (playdeck->id()>=line)) {
+	  playdeck->setId(playdeck->id()+1);
+	}
       }
     }
   }
@@ -699,9 +764,11 @@ void LogPlay::remove(int line,int num_lines,bool update,bool preserv_custom_tran
   int running=runningEvents(lines);
   for(int i=0;i<running;i++) {
     if((logline=logLine(lines[i]))!=NULL) {
-      playdeck=(RDPlayDeck *)logline->playDeck();
-      if((playdeck->id()>=0)&&(playdeck->id()>line)) {
-	playdeck->setId(playdeck->id()-num_lines);
+      if(logline->type()==RDLogLine::Cart) {
+	playdeck=(RDPlayDeck *)logline->playDeck();
+	if((playdeck->id()>=0)&&(playdeck->id()>line)) {
+	  playdeck->setId(playdeck->id()-num_lines);
+	}
       }
     }
   }
@@ -715,7 +782,6 @@ void LogPlay::remove(int line,int num_lines,bool update,bool preserv_custom_tran
       makeNext(nextLine()-num_lines);
     }
     UpdateStartTimes(line);
-    UpdatePostPoint(line-num_lines);
     if(size()==0) {
       emit reloaded();
     }
@@ -724,7 +790,8 @@ void LogPlay::remove(int line,int num_lines,bool update,bool preserv_custom_tran
     }
     emit transportChanged();
     SetTransTimer();
-    }
+    UpdatePostPoint();
+  }
 }
 
 
@@ -795,12 +862,11 @@ void LogPlay::move(int from_line,int to_line)
   RDLogEvent::move(from_line,to_line);
   if(from_line>to_line) {
     UpdateStartTimes(to_line);
-    UpdatePostPoint(to_line);
   }
   else {
     UpdateStartTimes(from_line);
-    UpdatePostPoint(from_line);
   }
+  UpdatePostPoint();
   emit inserted(to_line);
   for(int i=0;i<2;i++) {
     if(mod_line[i]>=0) {
@@ -861,6 +927,8 @@ int LogPlay::nextLine() const
 int LogPlay::nextLine(int line)
 {
   int lines[TRANSPORT_QUANTITY];
+
+  // FIXME: Do we really need this codeblock?
   transportEvents(lines);
   for(int i=0;i<(TRANSPORT_QUANTITY-1);i++) {
     if(line==lines[i]) {
@@ -874,6 +942,8 @@ int LogPlay::nextLine(int line)
       }
     }
   }
+  // End of FIXME
+
   for(int i=line+1;i<size();i++) {
     if(logLine(i)->status()==RDLogLine::Scheduled) {
       return i;
@@ -906,7 +976,12 @@ RDLogLine::TransType LogPlay::nextTrans(int line)
 {
   RDLogLine *logline;
 
-  if((logline=logLine(nextLine(line)))!=NULL) {
+//  if((logline=logLine(nextLine(line)))!=NULL) {
+
+  int next_line; 
+  next_line=nextLine(line);
+  logline=logLine(next_line);
+  if(logline!=NULL) {
     return logline->transType();
   }
   return RDLogLine::Stop;
@@ -940,7 +1015,9 @@ void LogPlay::transportEvents(int line[])
     }
     switch(logline->status()) {
 	case RDLogLine::Scheduled:
-	  line[count++]=i;
+	  if(count<TRANSPORT_QUANTITY) {
+	    line[count++]=i;
+	  }
 	  break;
 
 	default:
@@ -953,7 +1030,7 @@ void LogPlay::transportEvents(int line[])
 }
 
 
-int LogPlay::runningEvents(int lines[],bool include_paused)
+int LogPlay::runningEvents(int *lines, bool include_paused)
 {
   int count=0;
   int events[TRANSPORT_QUANTITY];
@@ -964,7 +1041,9 @@ int LogPlay::runningEvents(int lines[],bool include_paused)
     return 0;
   }
   for(int i=0;i<TRANSPORT_QUANTITY;i++) {
-    lines[i]=-1;
+    if (lines){
+      lines[i]=-1;
+    }
     table[i]=i;
   }
 
@@ -994,7 +1073,9 @@ int LogPlay::runningEvents(int lines[],bool include_paused)
       }
     }
   }
-
+  if (!lines){
+    return count;
+  }
   //
   // Sort 'Em (by start time)
   //
@@ -1017,6 +1098,7 @@ int LogPlay::runningEvents(int lines[],bool include_paused)
   for(int i=0;i<count;i++) {
     lines[i]=events[table[i]];
   }
+
   return count;
 }
 
@@ -1026,6 +1108,12 @@ void LogPlay::lineModified(int line)
   SetTransTimer();
   UpdateStartTimes(line);
   emit modified(line);
+  int lines[TRANSPORT_QUANTITY] = {-1};
+  int count;
+  count = runningEvents(lines,false);
+  if (count > 0){
+    line=lines[count-1];
+  }
   UpdatePostPoint(line);
   emit transportChanged();
 }
@@ -1073,8 +1161,7 @@ QTime LogPlay::nextStop() const
 
 bool LogPlay::running()
 {
-  int lines[TRANSPORT_QUANTITY];
-  if(runningEvents(lines)==0) {
+  if(runningEvents(NULL)==0) {
     return false;
   }
   return true;
@@ -1093,6 +1180,10 @@ void LogPlay::transTimerData()
   RDLogLine *logline=NULL;
   int grace=0;
 
+  if(play_grace_timer->isActive()) {
+    play_grace_timer->stop();
+  }
+
   if(play_op_mode==RDAirPlayConf::Auto) {
     if(!GetNextPlayable(&play_trans_line,false)) {
       SetTransTimer();
@@ -1103,11 +1194,13 @@ void LogPlay::transTimerData()
     }
     if((runningEvents(lines)==0)) {
       makeNext(play_trans_line);
-      StartEvent(play_trans_line,RDLogLine::Play,0,RDLogLine::StartTime);
+      if(logline->transType()!=RDLogLine::Stop || grace>=0) {
+        StartEvent(play_trans_line,RDLogLine::Play,0,RDLogLine::StartTime);
+      } 
     }
     else {
       if(logline==NULL) {
-	LogLine("  invalid logline");
+	LogLine(RDConfig::LogNotice,"  invalid logline");
 	SetTransTimer();
 	return;
       }
@@ -1125,19 +1218,18 @@ void LogPlay::transTimerData()
 	    break;
 
 	  case -1:
-	    if(logline->transType()==RDLogLine::Stop) {
-	      logline->setTransType(RDLogLine::Play);
-	    }
 	    makeNext(play_trans_line);
 	    break;
 	    
 	  default:
-	    logline->setGraceTime(0);
 	    if(logline->transType()==RDLogLine::Stop) {
 	      logline->setTransType(RDLogLine::Play);
 	    }
-	    play_trans_timer->start(1000*grace,true);
-	    return;
+	    logline->setStartTime(RDLogLine::Predicted,logline->
+				  startTime(RDLogLine::Predicted).
+				  addMSecs(grace));
+	    play_grace_line=play_trans_line;
+	    play_grace_timer->start(grace,true);
 	    break;
       }
     }
@@ -1146,6 +1238,33 @@ void LogPlay::transTimerData()
 }
 
 
+void LogPlay::graceTimerData()
+{
+  int lines[TRANSPORT_QUANTITY];
+
+  if(play_op_mode==RDAirPlayConf::Auto) {
+    if(!GetNextPlayable(&play_grace_line,false)) {
+      SetTransTimer();
+      return;
+    }
+    if((runningEvents(lines)==0)) {
+      makeNext(play_grace_line);
+      StartEvent(play_grace_line,RDLogLine::Play,0,RDLogLine::StartTime);
+    }
+    else {
+      makeNext(play_grace_line);
+      if(play_trans_length==0) {
+	StartEvent(play_grace_line,RDLogLine::Play,0,RDLogLine::StartTime);
+      }
+      else {
+	StartEvent(play_grace_line,RDLogLine::Segue,play_trans_length,
+		   RDLogLine::StartTime);
+      }
+    }
+  }
+}
+
+
 void LogPlay::playStateChangedData(int id,RDPlayDeck::State state)
 {
 #ifdef SHOW_SLOTS
@@ -1196,16 +1315,17 @@ void LogPlay::segueStartData(int id)
     return;
   }
   if((play_op_mode==RDAirPlayConf::Auto)&&
-     (next_logline->transType()==RDLogLine::Segue)&&
+     ((next_logline->transType()==RDLogLine::Segue))&&
      (logline->status()==RDLogLine::Playing)&&
      (logline->id()!=-1)) {
     if(!GetNextPlayable(&play_next_line,false)) {
       return;
     }
-    StartEvent(play_next_line,RDLogLine::Segue,
+    StartEvent(play_next_line,next_logline->transType(),
 	       logline->segueTail(next_logline->transType()),
 	       RDLogLine::StartSegue,-1,
-  	       logline->segueTail(next_logline->transType()));
+	       logline->segueTail(next_logline->transType()));
+    SetTransTimer();
   }
 }
 
@@ -1260,7 +1380,7 @@ void LogPlay::positionData(int id,int pos)
     return;
   }
   if(pos>logline->effectiveLength()) {
-    LogLine(QString().sprintf("*** position out of bounds on signal: Line: %d  Cart: %d  Pos: %d ***",line,logline->cartNumber(),logline->playPosition()));
+    LogLine(RDConfig::LogWarning,QString().sprintf("*** position out of bounds on signal: Line: %d  Cart: %d  Pos: %d ***",line,logline->cartNumber(),logline->playPosition()));
     return;
   }
   logline->setPlayPosition(pos);
@@ -1273,6 +1393,7 @@ void LogPlay::macroStartedData()
 #ifdef SHOW_SLOTS
   printf("macroStartedData()\n");
 #endif
+  play_macro_running=true;
   int line=play_macro_deck->line();
   RDLogLine *logline;
   if((logline=logLine(line))==NULL) {
@@ -1304,7 +1425,12 @@ void LogPlay::macroFinishedData()
 	       (RDLogLine::PlaySource)(play_id+1),RDAirPlayConf::TrafficMacro,
 	       play_onair_flag);
   }
+  play_macro_running=false;
   UpdatePostPoint(line+1);
+  if(play_refresh_pending) {
+    refresh();
+    play_refresh_pending=false;
+  }
   emit transportChanged();
 }
 
@@ -1370,11 +1496,11 @@ bool LogPlay::StartEvent(int line,RDLogLine::TransType trans_type,
   bool was_paused=false;
 
   if((logline=logLine(line))==NULL) {
-    SetTransTimer();
+//    SetTransTimer();
     return false;
   }
   if(logline->id()<0) {
-    SetTransTimer();
+//    SetTransTimer();
     return false;
   }
 
@@ -1470,17 +1596,23 @@ bool LogPlay::StartEvent(int line,RDLogLine::TransType trans_type,
 	logline->setPausePort(port);
 	logline->setPortName(GetPortName(playdeck->card(),
 					 playdeck->port()));
+	if(logline->portName().toInt()==2){
+	  playdeck->duckVolume(play_duck_volume_port2,0);
+	  }
+	else  {
+	  playdeck->duckVolume(play_duck_volume_port1,0);
+	  }
+		
 	if(!playdeck->setCart(logline,logline->status()!=RDLogLine::Paused)) {
 	  // No audio to play, so fake it
-/*
 	  logline->setZombified(true);
 	  playStateChangedData(playdeck->id(),RDPlayDeck::Playing);
 	  logline->setStatus(RDLogLine::Playing);
 	  playStateChangedData(playdeck->id(),RDPlayDeck::Finished);
 	  logline->setStatus(RDLogLine::Finished);
-*/
-	  syslog(LOG_USER|LOG_WARNING,"LogPlay::StartEvent(): no audio,CUT=%s",
-		 (const char *)logline->cutName());
+	  LogLine(RDConfig::LogErr,QString().
+		  sprintf("LogPlay::StartEvent(): no audio,CUT=%s",
+			  (const char *)logline->cutName()));
 	  rdairplay_conf->setLogCurrentLine(play_id,nextLine());
 	  return false;
 	}
@@ -1494,7 +1626,7 @@ bool LogPlay::StartEvent(int line,RDLogLine::TransType trans_type,
 			     playdeck->stream(),
 			     playdeck->port());
 	if((int)logline->playPosition()>logline->effectiveLength()) {
-	  LogLine(QString().sprintf("*** position out of bounds: Line: %d  Cart: %d  Pos: %d ***",line,logline->cartNumber(),logline->playPosition()));
+	  LogLine(RDConfig::LogWarning,QString().sprintf("*** position out of bounds: Line: %d  Cart: %d  Pos: %d ***",line,logline->cartNumber(),logline->playPosition()));
 	  logline->setPlayPosition(0);
 	}
 	playdeck->play(logline->playPosition(),-1,-1,duck_length);
@@ -1512,7 +1644,7 @@ bool LogPlay::StartEvent(int line,RDLogLine::TransType trans_type,
 	  rdevent_player->
 	    exec(logline->resolveWildcards(play_start_rml[aport]));
 	}
-	LogLine(QString().sprintf(
+	LogLine(RDConfig::LogInfo,QString().sprintf(
 		  "started audio cart: Line: %d  Cart: %u  Cut: %u Pos: %d  Card: %d  Stream: %d  Port: %d",
 		  line,logline->cartNumber(),
 		  playdeck->cut()->cutNumber(),
@@ -1566,15 +1698,16 @@ bool LogPlay::StartEvent(int line,RDLogLine::TransType trans_type,
 	  logline->setStatus(RDLogLine::Finished);
 	  FinishEvent(line);
 	  emit transportChanged();
-	  LogLine(QString().
+	  LogLine(RDConfig::LogInfo,QString().
 	     sprintf("asynchronously executed macro cart: Line: %d  Cart: %u",
 		     line,logline->cartNumber()));
 	}
 	else {
 	  play_macro_deck->load(logline->cartNumber());
 	  play_macro_deck->setLine(line);
-	  LogLine(QString().sprintf("started macro cart: Line: %d  Cart: %u",
-				    line,logline->cartNumber()));
+	  LogLine(RDConfig::LogInfo,QString().
+		  sprintf("started macro cart: Line: %d  Cart: %u",
+			  line,logline->cartNumber()));
 	  play_macro_deck->exec();
 	}
 	break;
@@ -1625,21 +1758,26 @@ bool LogPlay::StartEvent(int line,RDLogLine::TransType trans_type,
 	}
 	if(GetTransType(logline->markerLabel(),0)!=RDLogLine::Stop) {
 	  play_macro_deck->
-	    load(QString().sprintf("LL %d %s 0!",
+	    load(QString().sprintf("LL %d %s -2!",
 				   play_id+1,
 				   (const char *)logline->markerLabel()));
 	}
 	else {
-	  play_macro_deck->
+	 play_macro_deck->
+		load(QString().sprintf("LL %d %s -2!",
+		play_id+1,
+		(const char *)logline->markerLabel()));
+	 /* play_macro_deck->
 	    load(QString().sprintf("LL %d %s!",
 				   play_id+1,
-				   (const char *)logline->markerLabel()));
+				   (const char *)logline->markerLabel()));*/
 	}
 	play_macro_deck->setLine(line);
 	play_macro_deck->exec();
-	LogLine(QString().sprintf("chained to log: Line: %d  Log: %s",
-				  line,
-				  (const char *)logline->markerLabel()));
+	LogLine(RDConfig::LogInfo,QString().
+		sprintf("chained to log: Line: %d  Log: %s",
+			line,
+			(const char *)logline->markerLabel()));
 	break;
 
       default:
@@ -1649,14 +1787,14 @@ bool LogPlay::StartEvent(int line,RDLogLine::TransType trans_type,
     if((logline->state()==RDLogLine::Ok)||
        (logline->state()==RDLogLine::NoCart)||
        (logline->state()==RDLogLine::NoCut)) {
-      SetTransTimer();
+//      SetTransTimer();
       rdairplay_conf->setLogCurrentLine(play_id,nextLine());
       return true;
     }
     play_next_line++;
   }
   play_next_line=-1;
-  SetTransTimer();
+//  SetTransTimer();
   rdairplay_conf->setLogCurrentLine(play_id,nextLine());
   return true;
 }
@@ -1716,12 +1854,19 @@ void LogPlay::CleanupEvent(int id)
     return;
   }
   playdeck=(RDPlayDeck *)logline->playDeck();
-  LogLine(QString().
-  sprintf("finished event: Line: %d  Cart: %u  Cut: %u Card: %d  Stream: %d  Port: %d",
-	  line,logline->cartNumber(),
-	  playdeck->cut()->cutNumber(),
-	  playdeck->card(),
-	  playdeck->stream(),playdeck->port()));
+  if(playdeck->cut()==NULL) {
+    LogLine(RDConfig::LogErr,QString().
+	    sprintf("event failed: Line: %d  Cart: %u",line,
+		    logline->cartNumber()));
+  }
+  else {
+    LogLine(RDConfig::LogInfo,QString().
+	    sprintf("finished event: Line: %d  Cart: %u  Cut: %u Card: %d  Stream: %d  Port: %d",
+		    line,logline->cartNumber(),
+		    playdeck->cut()->cutNumber(),
+		    playdeck->card(),
+		    playdeck->stream(),playdeck->port()));
+  }
   RDLogLine *prev_logline;
   if((prev_logline=logLine(line-1))==NULL) {
   }
@@ -1797,9 +1942,6 @@ void LogPlay::UpdateStartTimes(int line)
 	stop_set=true;
       }
 
-//
-// FIXME: This corrupts start times for running events!
-//
       prev_total_length=logline->effectiveLength()-
 	logline->playPosition();
       prev_segue_length=
@@ -1807,20 +1949,25 @@ void LogPlay::UpdateStartTimes(int line)
       end_time=
 	time.addMSecs(logline->effectiveLength()-
 		      logline->playPosition());
-/*
+
       switch(logline->status()) {
-	  case RDLogLine::Scheduled:
-	  case RDLogLine::Paused:
-	    prev_total_length=logline->effectiveLength()-
-	      logline->playPosition();
-	    prev_segue_length=
-	      logline->segueLength(next_trans)-logline->playPosition();
-	    end_time=
-	      time.addMSecs(logline->effectiveLength()-
-			    logline->playPosition());
-	    break;
+      case RDLogLine::Scheduled:
+      case RDLogLine::Paused:
+	prev_total_length=logline->effectiveLength()-
+	  logline->playPosition();
+	prev_segue_length=
+	  logline->segueLength(next_trans)-logline->playPosition();
+	end_time=
+	  time.addMSecs(logline->effectiveLength()-
+			logline->playPosition());
+	break; 
+      default: 
+	prev_total_length=logline->effectiveLength();
+	prev_segue_length=
+	  logline->segueLength(next_trans);
+	end_time=
+	  time.addMSecs(logline->effectiveLength());
       }
-*/
     }
   }
   next_stop=GetNextStop(line);
@@ -1846,9 +1993,11 @@ void LogPlay::FinishEvent(int line)
 	if(play_next_line>=0) {
 	  if(logline->transType()==RDLogLine::Play) {
 	    StartEvent(play_next_line,RDLogLine::Play,0,RDLogLine::StartPlay);
+  	    SetTransTimer(QTime(),false);
 	  }
 	  if(logline->transType()==RDLogLine::Segue) {
 	    StartEvent(play_next_line,RDLogLine::Segue,0,RDLogLine::StartPlay);
+  	    SetTransTimer(QTime(),false);
 	  }
 	}
       }
@@ -1971,6 +2120,14 @@ QTime LogPlay::GetNextStop(int line)
   return time;
 }
 
+void LogPlay::UpdatePostPoint()
+{
+  int lines[TRANSPORT_QUANTITY] = {-1};
+  int count = runningEvents(lines,false);
+  if (count > 0){
+    UpdatePostPoint(lines[count -1]);
+  }
+}
 
 void LogPlay::UpdatePostPoint(int line)
 {
@@ -1996,9 +2153,8 @@ void LogPlay::UpdatePostPoint(int line)
   /*
   printf("UpdatePostPoint Line: %d  Post: %s  Actual: %s  Offset: %d\n",
 	 post_line,(const char *)post_time.toString("hh:mm:ss"),
-	 (const char *)start_time.toString("hh:mm:ss"),offset);
+	 (const char *)start_time.toString("hh:mm:ss"),offset); 
   */
-
   if((post_time!=play_post_time)||(start_time!=play_start_time)||
     (offset!=play_post_offset)) {
     play_post_time=post_time;
@@ -2025,6 +2181,7 @@ int LogPlay::NextPostPoint(int line,QTime *start,int *offset)
 	    *offset+=logLine(i)->segueLength(nextTrans(i));
 	  }
 	  else {
+
 	    if((logline->startTime(RDLogLine::Logged)>
 		QTime::currentTime().addMSecs(rdstation_conf->timeOffset()))) {
 	      return i;
@@ -2112,13 +2269,18 @@ QString LogPlay::GetPortName(int card,int port)
 }
 
 
-void LogPlay::SetTransTimer()
+void LogPlay::SetTransTimer(QTime current_time,bool stop)
 {
-  QTime current_time=QTime::currentTime();
+  if(current_time.isNull()) {
+    current_time=QTime::currentTime();
+  }
   RDLogLine *logline;
 
   if(play_trans_timer->isActive()) {
-    play_trans_timer->stop();
+    if(stop)
+	    play_trans_timer->stop();
+    else
+      return;
   }
   play_trans_line=-1;
   for(int i=0;i<size();i++) {
@@ -2193,7 +2355,7 @@ void LogPlay::FreePlayDeck(RDPlayDeck *deck)
 }
 
 
-bool LogPlay::GetNextPlayable(int *line,bool skip_meta)
+bool LogPlay::GetNextPlayable(int *line,bool skip_meta,bool forced_start)
 {
   RDLogLine *logline;
   RDLogLine *next_logline;
@@ -2215,7 +2377,8 @@ bool LogPlay::GetNextPlayable(int *line,bool skip_meta)
       emit modified(i);
     }
     else {
-      if(logline->status()==RDLogLine::Scheduled || logline->status()==RDLogLine::Auditioning) {
+      if(logline->status()==RDLogLine::Scheduled || logline->status()==RDLogLine::Paused || 
+		      logline->status()==RDLogLine::Auditioning) {
         if(((logline->transType()==RDLogLine::Stop)||
 	    (play_op_mode==RDAirPlayConf::LiveAssist))&&((i-skipped)!=*line)) {
 	  makeNext(i);
@@ -2235,10 +2398,19 @@ bool LogPlay::GetNextPlayable(int *line,bool skip_meta)
         else {
 //	  logline->setStatus(RDLogLine::Finished);
 	  logline->setStartTime(RDLogLine::Initial,QTime::currentTime());
-	  if((logline->transType()==RDLogLine::Stop)&&(!logline->zombified())) {
-	    emit modified(i);
-	    *line=i;
-	    return true;
+	  if((logline->transType()==RDLogLine::Stop)) {
+            if((logline->cutNumber()>=0)&&(!logline->zombified())) {
+                emit modified(i);
+	        *line=i;
+	        return true;
+	    }
+	    else {
+	      if(!forced_start) {
+                emit modified(i);
+	        *line=i;
+	        return true;
+	      }
+  	    }
 	  }
         }
         emit modified(i);
@@ -2403,67 +2575,72 @@ void LogPlay::ResolveNowNext(QString *str,RDLogLine **loglines)
   // NOW PLAYING Event
   //
   if(loglines[0]!=NULL) {
-    (*str).replace("%n",QString().sprintf("%06u",loglines[0]->cartNumber()));
-    (*str).replace("%g",loglines[0]->groupName());
-    (*str).replace("%t",loglines[0]->title());
-    (*str).replace("%a",loglines[0]->artist());
-    (*str).replace("%l",loglines[0]->album());
-    (*str).replace("%y",loglines[0]->year().toString("yyyy"));
-    (*str).replace("%b",loglines[0]->label());
-    (*str).replace("%c",loglines[0]->client());
-    (*str).replace("%e",loglines[0]->agency());
-    (*str).replace("%m",loglines[0]->composer());
-    (*str).replace("%p",loglines[0]->publisher());
-    (*str).replace("%u",loglines[0]->userDefined());
+    str->replace("%n",QString().sprintf("%06u",loglines[0]->cartNumber()));
+    str->replace("%h",QString().sprintf("%d",loglines[0]->effectiveLength()));
+    str->replace("%g",loglines[0]->groupName());
+    str->replace("%t",loglines[0]->title());
+    str->replace("%a",loglines[0]->artist());
+    str->replace("%l",loglines[0]->album());
+    str->replace("%y",loglines[0]->year().toString("yyyy"));
+    str->replace("%b",loglines[0]->label());
+    str->replace("%c",loglines[0]->client());
+    str->replace("%e",loglines[0]->agency());
+    str->replace("%m",loglines[0]->composer());
+    str->replace("%p",loglines[0]->publisher());
+    str->replace("%u",loglines[0]->userDefined());
   }
   else {   // No NOW PLAYING Event
-    (*str).replace("%n","");
-    (*str).replace("%g","");
-    (*str).replace("%t","");
-    (*str).replace("%a","");
-    (*str).replace("%l","");
-    (*str).replace("%y","");
-    (*str).replace("%b","");
-    (*str).replace("%c","");
-    (*str).replace("%e","");
-    (*str).replace("%m","");
-    (*str).replace("%p","");
-    (*str).replace("%u","");
+    str->replace("%n","");
+    str->replace("%h","");
+    str->replace("%g","");
+    str->replace("%t","");
+    str->replace("%a","");
+    str->replace("%l","");
+    str->replace("%y","");
+    str->replace("%b","");
+    str->replace("%c","");
+    str->replace("%e","");
+    str->replace("%m","");
+    str->replace("%p","");
+    str->replace("%u","");
   }
 
   //
   // NEXT Event
   //
   if(loglines[1]!=NULL) {
-    (*str).replace("%N",QString().sprintf("%06u",loglines[1]->cartNumber()));
-    (*str).replace("%G",loglines[1]->groupName());
-    (*str).replace("%T",loglines[1]->title());
-    (*str).replace("%A",loglines[1]->artist());
-    (*str).replace("%L",loglines[1]->album());
-    (*str).replace("%Y",loglines[1]->year().toString("yyyy"));
-    (*str).replace("%B",loglines[1]->label());
-    (*str).replace("%C",loglines[1]->client());
-    (*str).replace("%E",loglines[1]->agency());
-    (*str).replace("%M",loglines[1]->composer());
-    (*str).replace("%P",loglines[1]->publisher());
-    (*str).replace("%U",loglines[1]->userDefined());
+    str->replace("%N",QString().sprintf("%06u",loglines[1]->cartNumber()));
+    str->replace("%H",QString().sprintf("%d",loglines[1]->effectiveLength()));
+    str->replace("%G",loglines[1]->groupName());
+    str->replace("%T",loglines[1]->title());
+    str->replace("%A",loglines[1]->artist());
+    str->replace("%L",loglines[1]->album());
+    str->replace("%Y",loglines[1]->year().toString("yyyy"));
+    str->replace("%B",loglines[1]->label());
+    str->replace("%C",loglines[1]->client());
+    str->replace("%E",loglines[1]->agency());
+    str->replace("%M",loglines[1]->composer());
+    str->replace("%P",loglines[1]->publisher());
+    str->replace("%U",loglines[1]->userDefined());
   }
   else {   // No NEXT Event
-    (*str).replace("%N","");
-    (*str).replace("%G","");
-    (*str).replace("%T","");
-    (*str).replace("%A","");
-    (*str).replace("%L","");
-    (*str).replace("%Y","");
-    (*str).replace("%B","");
-    (*str).replace("%C","");
-    (*str).replace("%E","");
-    (*str).replace("%M","");
-    (*str).replace("%P","");
-    (*str).replace("%U","");
+    str->replace("%N","");
+    str->replace("%H","");
+    str->replace("%G","");
+    str->replace("%T","");
+    str->replace("%A","");
+    str->replace("%L","");
+    str->replace("%Y","");
+    str->replace("%B","");
+    str->replace("%C","");
+    str->replace("%E","");
+    str->replace("%M","");
+    str->replace("%P","");
+    str->replace("%U","");
   }
-  (*str).replace("%%","%");
-  (*str).replace("%r","\n");
+  str->replace("%%","%");
+  str->replace("%r","\n");
+  str->replace("%R","\r\n");
 }
 
 
@@ -2587,7 +2764,7 @@ RDLogLine::TransType LogPlay::GetTransType(const QString &logname,int line)
   name.replace(" ","_");
   QString sql=QString().sprintf("select TRANS_TYPE from %s_LOG where COUNT=%d",
 				(const char *)name,line);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->first()) {
     trans=(RDLogLine::TransType)q->value(0).toUInt();
   }
