@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_upload.cpp,v 1.14 2007/12/31 18:49:10 fredg Exp $
+//      $Id: edit_upload.cpp,v 1.15 2008-09-18 19:02:15 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -37,6 +37,7 @@
 #include <rdcut_path.h>
 #include <rdtextvalidator.h>
 #include <rdexport_settings_dialog.h>
+#include <rdescape_string.h>
 
 #include <edit_upload.h>
 #include <globals.h>
@@ -636,6 +637,20 @@ bool EditUpload::CheckFormat()
   }
   delete station;
 
+  QString sql;
+  RDSqlQuery *q;
+  sql=QString().sprintf("select STATION_NAME from ENCODERS \
+                         where (NAME=\"%s\")&&(STATION_NAME=\"%s\")",
+			(const char *)RDEscapeString(edit_settings.
+						     formatName()),
+			(const char *)RDEscapeString(edit_station_box->
+						     currentText()));
+  q=new RDSqlQuery(sql);
+  if(q->first()) {
+    res=true;
+  }
+  delete q;
+
   return res;
 }
 
