@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlogin.cpp,v 1.26 2007/09/14 14:06:57 fredg Exp $
+//      $Id: rdlogin.cpp,v 1.30 2008-07-26 00:01:39 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,6 +20,7 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <stdlib.h>
 
 #include <qapplication.h>
 #include <qwidget.h>
@@ -38,7 +39,7 @@
 #include <rdcmd_switch.h>
 #include <rdtextvalidator.h>
 #include <rddbheartbeat.h>
-
+#include <rddb.h>
 #include <rdlogin.h>
 
 
@@ -53,7 +54,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
 {
   QString str;
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   //
   // HACK: Disable the Broken Custom SuSE Dialogs
@@ -118,24 +119,12 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Open Database
   //
-  login_db=QSqlDatabase::addDatabase(login_config->mysqlDriver());
+  QString err(tr("rdlogin : "));
+  login_db = RDInitDb (&err);
   if(!login_db) {
-    QMessageBox::warning(this,tr("Can't Connect"),
-			 tr("Unable to connect to mySQL Server!"));
+    QMessageBox::warning(this,tr("Can't Connect"),err);
     exit(0);
   }
-  login_db->setDatabaseName(login_config->mysqlDbname());
-  login_db->setUserName(login_config->mysqlUsername());
-  login_db->setPassword(login_config->mysqlPassword());
-  login_db->setHostName(login_config->mysqlHostname());
-  if(!login_db->open()) {
-    QMessageBox::warning(this,tr("Can't Connect"),
-			 tr("Unable to connect to mySQL Server!"));
-    login_db->removeDatabase(login_config->mysqlDbname());
-    exit(0);
-  }
-  new RDDbHeartbeat(login_config->mysqlHeartbeatInterval(),this);
-
   //
   // RIPC Connection
   //
@@ -168,7 +157,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   login_username_box->setFocus();
   sql="select LOGIN_NAME from USERS where ADMIN_CONFIG_PRIV=\"N\"\
        order by LOGIN_NAME";
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     login_username_box->insertItem(q->value(0).toString());
   }
@@ -265,7 +254,7 @@ void MainWidget::userData()
 void MainWidget::loginData()
 {
   RDUser *user=new RDUser(login_username_box->currentText());
-  if(user->checkPassword(login_password_edit->text())) {
+  if(user->checkPassword(login_password_edit->text(),false)) {
     login_ripc->setUser(login_username_box->currentText());
     login_password_edit->clear();
     delete user;
@@ -320,15 +309,20 @@ int main(int argc,char *argv[])
 	  ".");
   a.installTranslator(&qt);
 
-  QTranslator libradio(0);
-  libradio.load(QString(PREFIX)+QString("/share/srlabs/libradio_")+
-		QTextCodec::locale(),".");
-  a.installTranslator(&libradio);
-
-  QTranslator tests(0);
-  tests.load(QString(PREFIX)+QString("/share/srlabs/rdlogin_")+
+  QTranslator rd(0);
+  rd.load(QString(PREFIX)+QString("/share/rivendell/librd_")+
 	     QTextCodec::locale(),".");
-  a.installTranslator(&tests);
+  a.installTranslator(&rd);
+
+  QTranslator rdhpi(0);
+  rdhpi.load(QString(PREFIX)+QString("/share/rivendell/librdhpi_")+
+	     QTextCodec::locale(),".");
+  a.installTranslator(&rdhpi);
+
+  QTranslator tr(0);
+  tr.load(QString(PREFIX)+QString("/share/rivendell/rdlogin_")+
+	     QTextCodec::locale(),".");
+  a.installTranslator(&tr);
 
   //
   // Start Event Loop
