@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_clock.cpp,v 1.19 2007/05/26 20:58:35 stgabriel Exp $
+//      $Id: edit_clock.cpp,v 1.22.2.1 2008-10-24 12:12:38 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -29,17 +29,16 @@
 #include <qtextedit.h>
 #include <qpainter.h>
 #include <qmessagebox.h>
-#include <qsqldatabase.h>
 #include <qcolordialog.h>
-
 #include <qspinbox.h>
 #include <qcombobox.h>
 
-#include <rconf.h>
-
+#include <rddb.h>
 #include <rd.h>
+#include <rdconf.h>
 #include <rdevent.h>
 #include <rdcreate_log.h>
+#include <rdescape_string.h>
 
 #include <edit_clock.h>
 #include <add_clock.h>
@@ -394,9 +393,8 @@ void EditClock::saveData()
 void EditClock::saveAsData()
 {
   QString clockname=edit_name;
-  QString clockname_esc;
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString str;
 
   if(!ValidateCode()) {
@@ -423,8 +421,9 @@ void EditClock::saveAsData()
   }
   sql=
     QString().sprintf("select SHORT_NAME from CLOCKS where SHORT_NAME=\"%s\"",
-		      (const char *)edit_shortname_edit->text());
-  q=new QSqlQuery(sql);
+		      (const char *)
+		      RDEscapeString(edit_shortname_edit->text()));
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     QMessageBox::warning(this,tr("Code Exists"),
 			 tr("The clock code is already in use!"));
@@ -439,12 +438,10 @@ void EditClock::saveAsData()
     return;
   }
   delete addclock;
-  clockname_esc=clockname;
   edit_name=clockname;
-  clockname_esc.replace(" ","_");
   sql=QString().sprintf("select NAME from CLOCKS where NAME=\"%s\"",
 			(const char *)clockname);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
     if(QMessageBox::question(this,tr("Clock Exists"),
 			     tr("Clock already exists!  Overwrite?"),QMessageBox::Yes,QMessageBox::No)!=QMessageBox::Yes) {
@@ -454,15 +451,11 @@ void EditClock::saveAsData()
   }
   delete q;
   edit_clock->setName(clockname);
-  sql=QString().sprintf("create table `%s_CLK` (\
-                         ID int unsigned auto_increment not null primary key,\
-                         EVENT_NAME char(64) not null,\
-                         START_TIME time not null,\
-                         LENGTH int not null,\
-                         INDEX EVENT_NAME_IDX (EVENT_NAME))",
-			(const char *)clockname_esc);
-  q=new QSqlQuery(sql);
+  sql=RDCreateClockTableSql(clockname);
+  q=new RDSqlQuery(sql);
   delete q;
+
+
   Save();
   edit_new_clocks->push_back(clockname);
   CopyClockPerms(old_name,clockname);
@@ -597,7 +590,7 @@ void EditClock::RefreshList(int select_line)
       item->setText(0,eventline->startTime().toString("mm:ss"));
       item->setText(1,eventline->startTime().
 		    addMSecs(eventline->length()).toString("mm:ss"));
-      item->setText(3,RGetTimeLength(eventline->length(),false,false));
+      item->setText(3,RDGetTimeLength(eventline->length(),false,false));
       item->setText(2,QString().sprintf("%s [%s]",
 		    (const char *)eventline->name(),
 		    (const char *)eventline->properties()));
@@ -616,7 +609,7 @@ void EditClock::RefreshList(int select_line)
 void EditClock::RefreshNames()
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   RDEventLine *eventline=NULL;
   RDListViewItem *item=(RDListViewItem *)edit_clocks_list->firstChild();
   while(item!=NULL) {
@@ -624,8 +617,8 @@ void EditClock::RefreshNames()
       if((eventline=edit_clock->eventLine(item->text(4).toInt()))!=NULL) {
 	sql=QString().sprintf("select PROPERTIES from EVENTS\
                                where NAME=\"%s\"",
-			      (const char *)eventline->name());
-	q=new QSqlQuery(sql);
+			      (const char *)RDEscapeString(eventline->name()));
+	q=new RDSqlQuery(sql);
 	if(q->next()) {
 	  item->
 	    setText(2,QString().sprintf("%s [%s]",
@@ -700,18 +693,19 @@ void EditClock::UpdateClock(int line)
 void EditClock::CopyClockPerms(QString old_name,QString new_name)
 {
   QString sql;
-  QSqlQuery *q;
-  QSqlQuery *q1;
+  RDSqlQuery *q;
+  RDSqlQuery *q1;
 
   sql=QString().sprintf("select SERVICE_NAME from CLOCK_PERMS where\
-                         CLOCK_NAME=\"%s\"",(const char *)old_name);
-  q=new QSqlQuery(sql);
+                         CLOCK_NAME=\"%s\"",
+			(const char *)RDEscapeString(old_name));
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     sql=QString().sprintf("insert into CLOCK_PERMS set\
                           CLOCK_NAME=\"%s\",SERVICE_NAME=\"%s\"",
-			  (const char *)new_name,
-			  (const char *)q->value(0).toString());
-    q1=new QSqlQuery(sql);
+			  (const char *)RDEscapeString(new_name),
+			  (const char *)RDEscapeString(q->value(0).toString()));
+    q1=new RDSqlQuery(sql);
     delete q1;
   }
   delete q;
@@ -725,11 +719,12 @@ void EditClock::AbandonClock(QString name)
   }
   QString sql=QString().sprintf("delete from CLOCKS where NAME=\"%s\"",
 				(const char *)name);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   delete q;
   name.replace(" ","_");
-  sql=QString().sprintf("drop table %s_CLK",(const char *)name);
-  q=new QSqlQuery(sql);
+  sql=QString().sprintf("drop table %s_CLK",
+			(const char *)RDEscapeStringSQLColumn(name));
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
@@ -741,13 +736,14 @@ bool EditClock::ValidateCode()
 			     tr("You must provide a clock code!"));
     return false;
   }
-  QSqlQuery *q=
-    new QSqlQuery(QString().
+  RDSqlQuery *q=
+    new RDSqlQuery(QString().
 		  sprintf("select SHORT_NAME from CLOCKS\
                                      where (SHORT_NAME=\"%s\")&&\
                                      (NAME!=\"%s\")",
-			  (const char *)edit_shortname_edit->text(),
-			  (const char *)edit_name));
+			  (const char *)
+			  RDEscapeString(edit_shortname_edit->text()),
+			  (const char *)RDEscapeString(edit_name)));
   if(q->next()) {
     QMessageBox::information(this,tr("Duplicate Code"),
 			     tr("That code is already in use!"));
