@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: local_macros.cpp,v 1.49 2008-09-30 18:19:44 fredg Exp $
+//      $Id: local_macros.cpp,v 1.49.2.1 2008-11-07 13:31:18 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -32,8 +32,12 @@
 
 void MainObject::gpiChangedData(int matrix,int line,bool state)
 {
-  // LogLine(RDConfig::LogWarning,QString().sprintf("gpiChangedData(%d,%d,%d)",matrix,line,state));
-
+  if(state) {
+    LogLine(RDConfig::LogInfo,QString().sprintf("GPI %d:%d ON",matrix,line+1));
+  }
+  else {
+    LogLine(RDConfig::LogInfo,QString().sprintf("GPI %d:%d OFF",matrix,line+1));
+  }
   ripcd_gpi_state[matrix][line]=state;
   BroadcastCommand(QString().sprintf("GI %d %d %d %d!",matrix,line,state,
 				     ripcd_gpi_mask[matrix][line]));
@@ -52,8 +56,12 @@ void MainObject::gpiChangedData(int matrix,int line,bool state)
 
 void MainObject::gpoChangedData(int matrix,int line,bool state)
 {
-  // LogLine(RDConfig::LogWarning,QString().sprintf("gpoChangedData(%d,%d,%d)",matrix,line,state));
-
+  if(state) {
+    LogLine(RDConfig::LogInfo,QString().sprintf("GPO %d:%d ON",matrix,line+1));
+  }
+  else {
+    LogLine(RDConfig::LogInfo,QString().sprintf("GPO %d:%d OFF",matrix,line+1));
+  }
   ripcd_gpo_state[matrix][line]=state;
   BroadcastCommand(QString().sprintf("GO %d %d %d %d!",matrix,line,state,
 				     ripcd_gpo_mask[matrix][line]));
