@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: sas64000.h,v 1.4 2007/02/14 21:57:04 fredg Exp $
+//      $Id: sas64000.h,v 1.5 2007-09-14 14:06:59 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -45,7 +45,7 @@ class Sas64000 : public QObject
 
  private:
   void SendCommand(RDMacro *cmd,char *format);
-  RTTYDevice *sas_device;
+  RDTTYDevice *sas_device;
   int sas_inputs;
   int sas_outputs;
 };
