@@ -5,7 +5,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: sas64000gpi.h,v 1.3 2007/02/14 21:57:04 fredg Exp $
+//      $Id: sas64000gpi.h,v 1.5 2008-09-30 18:19:45 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -30,7 +30,7 @@
 #include <rdmatrix.h>
 #include <rdmacro.h>
 #include <rdtty.h>
-
+#include <rdoneshot.h>
 
 class Sas64000Gpi : public QObject
 {
@@ -39,13 +39,18 @@ class Sas64000Gpi : public QObject
   Sas64000Gpi(RDMatrix *matrix,QObject *parent=0,const char *name=0);
   ~Sas64000Gpi();
   void processCommand(RDMacro *cmd);
-  void processStatus(char *buf,int size);
 
  signals:
   void rmlEcho(RDMacro *cmd);
+  void gpoChanged(int matrix,int line,bool state);
+
+ private slots:
+  void gpoOneshotData(void *data);
 
  private:
-  RTTYDevice *sas_device;
+  RDTTYDevice *sas_device;
+  RDOneShot *sas_gpo_oneshot;
+  int sas_matrix;
   int sas_inputs;
   int sas_outputs;
   int sas_gpis;
