@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdgpimon.cpp,v 1.7 2007/11/12 18:43:29 fredg Exp $
+//      $Id: rdgpimon.cpp,v 1.10 2008-09-30 18:19:47 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,6 +20,7 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <stdlib.h>
 
 #include <qapplication.h>
 #include <qwidget.h>
@@ -109,13 +110,20 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   // RIPC Connection
   //
   gpi_ripc=new RDRipc(gpi_config->stationName());
+  gpi_ripc->setIgnoreMask(true);
   connect(gpi_ripc,SIGNAL(userChanged()),this,SLOT(userData()));
   connect(gpi_ripc,SIGNAL(gpiStateChanged(int,int,bool)),
 	  this,SLOT(gpiStateChangedData(int,int,bool)));
+  connect(gpi_ripc,SIGNAL(gpoStateChanged(int,int,bool)),
+	  this,SLOT(gpoStateChangedData(int,int,bool)));
   connect(gpi_ripc,SIGNAL(gpiMaskChanged(int,int,bool)),
 	  this,SLOT(gpiMaskChangedData(int,int,bool)));
+  connect(gpi_ripc,SIGNAL(gpoMaskChanged(int,int,bool)),
+	  this,SLOT(gpoMaskChangedData(int,int,bool)));
   connect(gpi_ripc,SIGNAL(gpiCartChanged(int,int,int)),
 	  this,SLOT(gpiCartChangedData(int,int,int)));
+  connect(gpi_ripc,SIGNAL(gpoCartChanged(int,int,int)),
+	  this,SLOT(gpoCartChangedData(int,int,int)));
   gpi_ripc->connectHost("localhost",RIPCD_TCP_PORT,gpi_config->password());
 
   //
@@ -128,17 +136,31 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   gpi_matrix=NULL;
 
+  //
+  // Type Selector
+  //
+  gpi_type_box=new QComboBox(this,"gpi_type_box");
+  gpi_type_box->setGeometry(80,10,120,21);
+  gpi_type_box->insertItem(tr("GPI (Inputs)"));
+  gpi_type_box->insertItem(tr("GPO (Outputs)"));
+  QLabel *label=
+    new QLabel(gpi_type_box,tr("Show:"),this,"gpi_type_label");
+  label->setGeometry(20,10,55,21);
+  label->setFont(font);
+  label->setAlignment(AlignRight|AlignVCenter);
+  connect(gpi_type_box,SIGNAL(activated(int)),
+	  this,SLOT(matrixActivatedData(int)));
+
   //
   // Matrix Selector
   //
   gpi_matrix_box=new QComboBox(this,"gpi_matrix_box");
-  gpi_matrix_box->setGeometry(80,10,80,21);
+  gpi_matrix_box->setGeometry(280,10,80,21);
   for(int i=0;i<MAX_MATRICES;i++) {
     gpi_matrix_box->insertItem(QString().sprintf("%d",i));
   }
-  QLabel *label=
-    new QLabel(gpi_matrix_box,tr("Matrix:"),this,"gpi_matrix_label");
-  label->setGeometry(20,10,55,21);
+  label=new QLabel(gpi_matrix_box,tr("Matrix:"),this,"gpi_matrix_label");
+  label->setGeometry(220,10,55,21);
   label->setFont(font);
   label->setAlignment(AlignRight|AlignVCenter);
   connect(gpi_matrix_box,SIGNAL(activated(int)),
@@ -220,17 +242,33 @@ void MainWidget::userData()
 }
 
 
+void MainWidget::typeActivatedData(int index)
+{
+}
+
+
 void MainWidget::matrixActivatedData(int index)
 {
   if(gpi_matrix!=NULL) {
     delete gpi_matrix;
   }
-  gpi_matrix=new RDMatrix(gpi_config->stationName(),index);
+  gpi_matrix=
+    new RDMatrix(gpi_config->stationName(),gpi_matrix_box->currentItem());
   UpdateLabelsDown(0);
   gpi_up_button->setDisabled(true);
-  gpi_ripc->sendGpiStatus(index);
-  gpi_ripc->sendGpiMask(index);
-  gpi_ripc->sendGpiCart(index);
+  switch((RDMatrix::GpioType)gpi_type_box->currentItem()) {
+    case RDMatrix::GpioInput:
+      gpi_ripc->sendGpiStatus(gpi_matrix_box->currentItem());
+      gpi_ripc->sendGpiMask(gpi_matrix_box->currentItem());
+      gpi_ripc->sendGpiCart(gpi_matrix_box->currentItem());
+      break;
+
+    case RDMatrix::GpioOutput:
+      gpi_ripc->sendGpoStatus(gpi_matrix_box->currentItem());
+      gpi_ripc->sendGpoMask(gpi_matrix_box->currentItem());
+      gpi_ripc->sendGpoCart(gpi_matrix_box->currentItem());
+      break;
+  }
 }
 
 
@@ -238,6 +276,27 @@ void MainWidget::gpiStateChangedData(int matrix,int line,bool state)
 {
   // printf("gpiStateChanged(%d,%d,%d)\n",matrix,line,state);
 
+  if(gpi_type_box->currentItem()!=RDMatrix::GpioInput) {
+    return;
+  }
+  if(matrix!=gpi_matrix->matrix()) {
+    return;
+  }
+  for(int i=0;i<(GPIMON_ROWS*GPIMON_COLS);i++) {
+    if(gpi_labels[i]->line()==line) {
+      gpi_labels[i]->setState(state);
+    }
+  }
+}
+
+
+void MainWidget::gpoStateChangedData(int matrix,int line,bool state)
+{
+  // printf("gpoStateChanged(%d,%d,%d)\n",matrix,line,state);
+
+  if(gpi_type_box->currentItem()!=RDMatrix::GpioOutput) {
+    return;
+  }
   if(matrix!=gpi_matrix->matrix()) {
     return;
   }
@@ -251,6 +310,25 @@ void MainWidget::gpiStateChangedData(int matrix,int line,bool state)
 
 void MainWidget::gpiMaskChangedData(int matrix,int line,bool state)
 {
+  if(gpi_type_box->currentItem()!=RDMatrix::GpioInput) {
+    return;
+  }
+  if(matrix!=gpi_matrix->matrix()) {
+    return;
+  }
+  for(int i=0;i<(GPIMON_ROWS*GPIMON_COLS);i++) {
+    if(gpi_labels[i]->line()==line) {
+      gpi_labels[i]->setMask(state);
+    }
+  }
+}
+
+
+void MainWidget::gpoMaskChangedData(int matrix,int line,bool state)
+{
+  if(gpi_type_box->currentItem()!=RDMatrix::GpioOutput) {
+    return;
+  }
   if(matrix!=gpi_matrix->matrix()) {
     return;
   }
@@ -264,6 +342,28 @@ void MainWidget::gpiMaskChangedData(int matrix,int line,bool state)
 
 void MainWidget::gpiCartChangedData(int matrix,int line,int cartnum)
 {
+  if(gpi_type_box->currentItem()!=RDMatrix::GpioInput) {
+    return;
+  }
+  if(cartnum<0) {
+    cartnum=0;
+  }
+  if(matrix!=gpi_matrix->matrix()) {
+    return;
+  }
+  for(int i=0;i<(GPIMON_ROWS*GPIMON_COLS);i++) {
+    if(gpi_labels[i]->line()==line) {
+      gpi_labels[i]->setCart(cartnum);
+    }
+  }
+}
+
+
+void MainWidget::gpoCartChangedData(int matrix,int line,int cartnum)
+{
+  if(gpi_type_box->currentItem()!=RDMatrix::GpioOutput) {
+    return;
+  }
   if(cartnum<0) {
     cartnum=0;
   }
@@ -311,14 +411,25 @@ void MainWidget::UpdateLabelsUp(int last_line)
   int count=0;
   int count_limit=GPIMON_ROWS*GPIMON_COLS;
   bool last_updated=false;
+  QString tablename="GPIS";
 
   for(int i=0;i<(GPIMON_ROWS*GPIMON_COLS);i++) {
     gpi_labels[i]->hide();
   }
-  sql=QString().sprintf("select NUMBER,MACRO_CART from GPIS \
+  switch((RDMatrix::GpioType)gpi_type_box->currentItem()) {
+    case RDMatrix::GpioInput:
+      tablename="GPIS";
+      break;
+
+    case RDMatrix::GpioOutput:
+      tablename="GPOS";
+      break;
+  }
+  sql=QString().sprintf("select NUMBER,MACRO_CART from %s \
                          where (STATION_NAME=\"%s\")&&\
                          (MATRIX=%d)&&\
                          (NUMBER<=%d) order by NUMBER desc",
+			(const char *)tablename,
 			(const char *)gpi_station->name(),
 			gpi_matrix->matrix(),last_line);
   q=new RDSqlQuery(sql);
@@ -347,14 +458,25 @@ void MainWidget::UpdateLabelsDown(int first_line)
   RDSqlQuery *q;
   int count=0;
   bool first_updated=false;
+  QString tablename="GPIS";
 
   for(int i=0;i<(GPIMON_ROWS*GPIMON_COLS);i++) {
     gpi_labels[i]->hide();
   }
-  sql=QString().sprintf("select NUMBER,MACRO_CART from GPIS \
+  switch((RDMatrix::GpioType)gpi_type_box->currentItem()) {
+    case RDMatrix::GpioInput:
+      tablename="GPIS";
+      break;
+
+    case RDMatrix::GpioOutput:
+      tablename="GPOS";
+      break;
+  }
+  sql=QString().sprintf("select NUMBER,MACRO_CART from %s \
                          where (STATION_NAME=\"%s\")&&\
                          (MATRIX=%d)&&\
                          (NUMBER>=%d) order by NUMBER",
+			(const char *)tablename,
 			(const char *)gpi_station->name(),
 			gpi_matrix->matrix(),first_line);
   q=new RDSqlQuery(sql);
@@ -386,15 +508,20 @@ int main(int argc,char *argv[])
 	  ".");
   a.installTranslator(&qt);
 
-  QTranslator libradio(0);
-  libradio.load(QString(PREFIX)+QString("/share/srlabs/libradio_")+
-		QTextCodec::locale(),".");
-  a.installTranslator(&libradio);
-
-  QTranslator tests(0);
-  tests.load(QString(PREFIX)+QString("/share/srlabs/rdutils_")+
+  QTranslator rd(0);
+  rd.load(QString(PREFIX)+QString("/share/rivendell/librd_")+
 	     QTextCodec::locale(),".");
-  a.installTranslator(&tests);
+  a.installTranslator(&rd);
+
+  QTranslator rdhpi(0);
+  rdhpi.load(QString(PREFIX)+QString("/share/rivendell/librdhpi_")+
+	     QTextCodec::locale(),".");
+  a.installTranslator(&rdhpi);
+
+  QTranslator tr(0);
+  tr.load(QString(PREFIX)+QString("/share/rivendell/rdutils_")+
+	     QTextCodec::locale(),".");
+  a.installTranslator(&tr);
 
   //
   // Start Event Loop
